package com.huigou.uasp.builder.filer;

import com.google.common.base.CaseFormat;
import com.huigou.uasp.builder.BuildFilerInter;
import com.huigou.uasp.builder.vo.ParamFormVO;
import com.huigou.uasp.util.Utils;
import java.io.File;
import java.util.List;
import java.util.Map;
import org.springframework.stereotype.Service;

@Service("buildEntityFile")
public class BuildEntityFile implements BuildFilerInter {
   private List<Map<String, Object>> fieldList;

   public String generateFile(ParamFormVO paraForm, List<Map<String, Object>> fieldList) throws Exception {
      File file = new File(paraForm.getSrcPath() + "/domain");
      if (!file.exists()) {
         file.mkdir();
         file = new File(paraForm.getSrcPath() + "/domain/model");
         file.mkdir();
      }

      String clsName = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, paraForm.getTableName());
      clsName = Utils.toUpperCaseFirstOne(clsName);
      StringBuffer sb = new StringBuffer("");
      sb.append("package ").append(paraForm.getPackageName()).append(".domain.model;\r\n ");
      sb.append("import java.util.Date;\r\n ");
      sb.append("import java.lang.Double;\r\n ");
      sb.append("import javax.persistence.Column;\r\n ");
      sb.append("import javax.persistence.Embedded;\r\n ");
      sb.append("import javax.persistence.Entity;\r\n ");
      sb.append("import javax.persistence.EntityListeners;\r\n ");
      sb.append("import javax.persistence.Table;\r\n ");
      sb.append("import javax.persistence.Transient;\r\n ");
      sb.append("import com.huigou.data.domain.listener.CreatorAndModifierListener;\r\n ");
      sb.append("import com.huigou.data.domain.model.AbstractEntity;\r\n ");
      sb.append("import com.huigou.data.domain.model.Creator;\r\n ");
      sb.append(" \r\n");
      String colName = "";
      String dataType = "";
      String comments = "";
      String dataLength = "";
      String dtype = "String";
      int dataScale = 0;
      Map map = null;
      boolean isCreator = false;

      int u;
      for(u = 0; u < fieldList.size(); ++u) {
         map = (Map)fieldList.get(u);
         colName = map.get("columnName").toString();
         if ("created_by_id".equals(colName)) {
            isCreator = true;
            break;
         }
      }

      sb.append(" @Entity\r\n ");
      sb.append("@Table(name = \"").append(paraForm.getTableName()).append("\") \r\n");
      if (isCreator) {
         sb.append("@EntityListeners({ CreatorAndModifierListener.class }) \r\n");
      }

      sb.append("public class " + clsName + " extends AbstractEntity{ \r\n ");
      sb.append("  private static final long serialVersionUID = 1L; \r\n ");

      for(u = 0; u < fieldList.size(); ++u) {
         map = (Map)fieldList.get(u);
         colName = map.get("columnName").toString();
         dataType = map.get("dataType").toString();
         dataLength = map.get("dataLength").toString();
         comments = map.get("comments").toString();
         int scale = !"".equals(map.get("dataScale")) ? Integer.parseInt(map.get("dataScale").toString()) : 0;
         if (!"id".equals(colName) && !"version".equals(colName) && !"created_date".equals(colName) && !"created_by_name".equals(colName) && !"created_by_id".equals(colName)) {
            sb.append("/** \r\n").append("  * ").append(comments).append("\r\n */\r\n ");
            sb.append(" @Column(name=\"").append(colName).append("\",length=").append(dataLength).append(") \r\n ");
            colName = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, colName);
            if ("date".equals(dataType)) {
               dtype = "Date";
            }

            if ("number".equals(dataType)) {
               if (scale > 0) {
                  dtype = "Double";
               } else {
                  dtype = "Integer";
               }
            }

            sb.append(" private ").append(dtype).append(" ").append(colName).append("; \r\n ");
            sb.append(" \r\n");
            sb.append(" public ").append(dtype).append(" get").append(Utils.toUpperCaseFirstOne(colName)).append("() { \r\n ");
            sb.append("    return ").append(colName).append("; \r\n } \r\n ");
            sb.append("public void set").append(Utils.toUpperCaseFirstOne(colName)).append("(").append(dtype).append("  ").append(colName).append(") { \r\n ");
            sb.append("  this.").append(colName).append(" = ").append(colName).append("; \r\n  } \r\n ");
         }
      }

      if (isCreator) {
         sb.append(" /** \r\n");
         sb.append(" * 创建人信息 \r\n");
         sb.append(" */ \r\n ");
         sb.append(" @Embedded \r\n");
         sb.append(" private Creator creator; \r\n");
      }

      sb.append("}");
      String realPath = paraForm.getUploadPath() + "/" + paraForm.getPackageName().replaceAll("\\.", "/");
      realPath = realPath + "/domain/model/" + clsName + ".java";
      return Utils.generateJava(realPath, sb);
   }
}
