package com.huigou.uasp.builder.filer;

import com.google.common.base.CaseFormat;
import com.huigou.uasp.builder.BuildFilerInter;
import com.huigou.uasp.builder.FieldTagTypeInter;
import com.huigou.uasp.builder.pagetag.CheckboxTagResult;
import com.huigou.uasp.builder.pagetag.DateTagResult;
import com.huigou.uasp.builder.pagetag.InputTagResult;
import com.huigou.uasp.builder.pagetag.RadiosTagResult;
import com.huigou.uasp.builder.pagetag.SelectTagResult;
import com.huigou.uasp.builder.pagetag.TextAreaTagResult;
import com.huigou.uasp.builder.vo.FieldAttributeVO;
import com.huigou.uasp.builder.vo.ParamFormVO;
import com.huigou.uasp.util.Utils;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Queue;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service("buildPageDetailFile")
public class BuildPageDetailFile implements BuildFilerInter {
   @Autowired
   private BuildPageJSFile buildPageJSFile;

   public String generateFile(ParamFormVO paraForm, List<Map<String, Object>> fieldList) throws Exception {
      String entityName = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, paraForm.getTableName());
      StringBuffer sb = this.generateContents(paraForm, entityName);
      String filePathName = paraForm.getUploadPath() + "/" + paraForm.getFormPath() + "/" + entityName + "Detail.jsp";
      return Utils.generateFile(filePathName, sb);
   }

   public String generateFile(String filePathName, StringBuffer sb) throws Exception {
      return Utils.generateFile(filePathName, sb);
   }

   public StringBuffer generateContents(ParamFormVO paraForm, String mainTableName) {
      StringBuffer sb = new StringBuffer("");
      sb.append("<%@ page contentType=\"text/html; charset=utf-8\" language=\"java\"%>\r\n");
      sb.append("<%@ taglib uri=\"/WEB-INF/taglib.tld\" prefix=\"x\"%>\r\n");
      sb.append("<%@ taglib uri=\"http://java.sun.com/jsp/jstl/core\" prefix=\"c\"%>\r\n");
      if (paraForm.getDetails() != null && paraForm.getDetails().size() > 0) {
         this.generateDetailFile(paraForm, mainTableName, sb);
      }

      String entityName = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, mainTableName);
      if (paraForm.getIsform() == 1) {
         sb.append("<form class=\"hg-form\" method=\"post\" action=\"\" id=\"dataRecordForm\">\r\n");
      } else {
         sb.append("<form class=\"hg-form\" method=\"post\" action=\"\" id=\"").append(entityName).append("Form\">\r\n");
      }

      Iterator paraDetail = paraForm.getHiddenFields().iterator();

      while(paraDetail.hasNext()) {
         String hiddenField = (String)paraDetail.next();
         sb.append("   <x:hidden name=\"").append(hiddenField).append("\" />\r\n");
      }

      sb.append(" <div class=\"hg-form-cols\"> \r\n");
      sb.append("  <div class=\"hg-form-row\">\r\n");
      sb.append("    </div>\r\n");
      this.generateFieldTag(paraForm, sb);
      if (paraForm.getExistAttachment() == 1) {
         sb.append("<div class=\"hg-form-row\">\r\n");
         sb.append("   <x:fileList bizCode=\"").append(entityName).append("Id\" bizId=\"attbizid\" id=\"").append(entityName).append("List\" title=\"相关附件\" />\r\n");
         sb.append("</div>\r\n");
      }

      sb.append(" </div>\r\n");
      sb.append("</form>\r\n");
      if (paraForm.getDetails() != null && paraForm.getDetails().size() > 0) {
         List<ParamFormVO> listDetails = paraForm.getDetails();
         paraDetail = null;
         String gridName = "";

         for(int j = 0; j < listDetails.size(); ++j) {
            ParamFormVO paramDetails = (ParamFormVO)listDetails.get(j);
            gridName = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, paramDetails.getTableName());
            sb.append("<div class=\"clearfix\"></div>\r\n");
            sb.append("<div><font style=\"font-weight:bold;font-size:inherit\">&nbsp;&nbsp;").append(paramDetails.getFormName()).append("列表  </font><br></div>\r\n");
            sb.append(" <div id=\"").append(gridName).append("Grid\" style=\"margin: 2px;\"></div>\r\n");
         }
      }

      return sb;
   }

   public void generateFieldTag(ParamFormVO paraForm, StringBuffer sb) {
      String[] fieldEns = paraForm.getFieldEns();
      String[] fieldChs = paraForm.getFieldChs();
      String[] fieldTags = paraForm.getFieldTags();
      String[] mustinputField = paraForm.getMustinputFields();
      String[] fieldsLengths = paraForm.getFieldsLengths();
      Integer[] readOnlys = paraForm.getReadOnlys();
      String[] validatorTypes = paraForm.getValidatorTypes();
      String[] codeRuleIds = paraForm.getCodeRuleId();
      String fieldEn = "";
      int rows = this.countRows(paraForm);
      int cols = Integer.parseInt(paraForm.getPagedatailCols());
      int x = 0;
      Queue<String> queue = new ArrayDeque();

      for(int y = 0; y < fieldEns.length; ++y) {
         queue.add(fieldEns[y]);
      }

      new ArrayList();
      FieldTagTypeInter outResults = null;
      FieldAttributeVO fieldAttributes = null;

      for(int i = 0; i < rows && !queue.isEmpty(); ++i) {
         sb.append("  <div class=\"hg-form-row\">\r\n");

         for(int r = 0; r < cols && !queue.isEmpty(); ++r) {
            fieldEn = (String)queue.poll();

            for(int y = 0; y < fieldEns.length; ++y) {
               if (fieldEn.equals(fieldEns[y])) {
                  x = y;
                  break;
               }
            }

            outResults = this.getFieldTagType(fieldTags[x]);
            fieldAttributes = new FieldAttributeVO();
            fieldAttributes.setFieldEn(fieldEns[x]);
            fieldAttributes.setFieldCh(fieldChs[x]);
            if (codeRuleIds != null) {
               fieldAttributes.setCodeRuleId(codeRuleIds[x]);
            }

            fieldAttributes.setFieldLength(Integer.parseInt(!"".equals(fieldsLengths[x]) ? fieldsLengths[x] : "0"));
            fieldAttributes.setReadOnly(readOnlys[x]);
            fieldAttributes.setLabelCols(paraForm.getLabelCols());
            fieldAttributes.setFieldCols(paraForm.getFieldCols());
            fieldAttributes.setMustinputField("1".equals(mustinputField[x]) ? "true" : "false");
            fieldAttributes.setTextAreaRows(paraForm.getTextAreaRows());
            fieldAttributes.setCols(cols);
            fieldAttributes.setCurrCols(r);
            if (validatorTypes.length > x) {
               fieldAttributes.setValidatorType(validatorTypes[x]);
            }

            if (paraForm.getDataSourceTypes().length > x) {
               fieldAttributes.setDataSourceType(paraForm.getDataSourceTypes()[x]);
            }

            if (paraForm.getDataSources().length > x) {
               fieldAttributes.setDataSource(paraForm.getDataSources()[x]);
            }

            if (paraForm.getCssStyle().length > x) {
               fieldAttributes.setCssStyle(paraForm.getCssStyle()[x]);
            }

            if (paraForm.getCheckFunction().length > x) {
               fieldAttributes.setCheckFunction(paraForm.getCheckFunction()[x]);
            }

            List<String> list = outResults.processOutResult(sb, fieldAttributes);
            r = Integer.parseInt((String)list.get(1));
            if (x < fieldEns.length - 1 && "textarea".equals(fieldTags[x + 1])) {
               r = cols;
            }
         }

         sb.append("  </div>\r\n");
      }

   }

   public void generateDetailFile(ParamFormVO paraForm, String mainTableName, StringBuffer sb) {
      sb.append(" <head> \r\n");
      List<ParamFormVO> listDetails = paraForm.getDetails();
      ParamFormVO paraDetail = null;
      sb.append(" <script type=\"text/javascript\">\r\n");
      sb.append("    bindEvent();  \r\n");
      Utils.composeMainFormCheckFunction(paraForm, sb);
      sb.append(" </script> \r\n");
      String formNo = paraForm.getFormPath();
      formNo = formNo.substring(formNo.indexOf("customform") + 11);
      String queryUrl = "";

      for(int j = 0; j < listDetails.size(); ++j) {
         paraDetail = (ParamFormVO)listDetails.get(j);
         String entitySubTable = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, paraDetail.getTableName());
         sb.append(" <script src='<c:url value=\"").append(paraForm.getSrcPath()).append("/").append(formNo).append("/").append(entitySubTable).append(".js\"/>' type=\"text/javascript\"></script>\r\n");
         String detailTableName = paraDetail.getTableName();
         paraDetail.setTableName(detailTableName.toLowerCase());
         paraDetail.setBtnNames(new String[]{"新增行", "删除行", "保存行", "启用行", "禁用行"});
         paraDetail.setBtnMethodNames(new String[]{"addRow", "deleteRow", "saveRow", "enableRow", "disableRow"});
         if (this.buildPageJSFile == null) {
            this.buildPageJSFile = new BuildPageJSFile();
         }

         if (paraForm.getIsform() == 1) {
            queryUrl = "'/dataManage/slicedQueryDataRecordDetail.ajax'";
         } else {
            queryUrl = "'/dataManage/slicedQuery" + entitySubTable + "Detail.ajax";
         }

         queryUrl = queryUrl + "?maiTab=" + mainTableName;
         queryUrl = queryUrl + "&subTab=" + detailTableName;
         queryUrl = queryUrl + "&formId=$(\"#formId\").val()";
         queryUrl = queryUrl + "+'&id='+$(\"#id\").val()";
         StringBuffer sbjs = this.buildPageJSFile.generateContents(paraDetail, mainTableName, paraForm.getRealFieldEns(), true, queryUrl);
         Utils.generateFile(paraForm.getFormPath() + "/" + entitySubTable + ".js", sbjs);
      }

      sb.append(" </head> \r\n");
   }

   public int countRows(ParamFormVO paraForm) {
      int cols = Integer.parseInt(paraForm.getPagedatailCols());
      String[] fieldTags = paraForm.getFieldTags();
      String[] fieldEns = paraForm.getFieldEns();
      int areaCols = 0;

      int y;
      for(y = 0; y < fieldTags.length; ++y) {
         if ("textarea".equals(fieldTags[y])) {
            ++areaCols;
         }

         if (y % cols != 0) {
            ++areaCols;
         }
      }

      y = (fieldEns.length - areaCols) % cols;
      int rows = (fieldEns.length - areaCols) / cols;
      if (y != 0) {
         ++rows;
      }

      rows += areaCols;
      return rows;
   }

   public FieldTagTypeInter getFieldTagType(String condition) {
      FieldTagTypeInter inter = null;
      switch(condition.hashCode()) {
      case -1003243718:
         if (condition.equals("textarea")) {
            inter = new TextAreaTagResult();
         }
         break;
      case -906021636:
         if (condition.equals("select")) {
            inter = new SelectTagResult();
         }
         break;
      case 3076014:
         if (condition.equals("date")) {
            inter = new DateTagResult();
         }
         break;
      case 3556653:
         if (condition.equals("text")) {
            inter = new InputTagResult();
         }
         break;
      case 108270587:
         if (condition.equals("radio")) {
            inter = new RadiosTagResult();
         }
         break;
      case 1536891843:
         if (condition.equals("checkbox")) {
            inter = new CheckboxTagResult();
         }
      }

      return (FieldTagTypeInter)inter;
   }
}
