package com.huigou.uasp.data.application.impl;

import com.google.common.base.CaseFormat;
import com.huigou.context.Operator;
import com.huigou.context.ThreadLocalUtil;
import com.huigou.data.query.model.QueryDescriptor;
import com.huigou.data.query.model.QueryModel;
import com.huigou.exception.ApplicationException;
import com.huigou.uasp.bmp.common.application.BaseApplication;
import com.huigou.uasp.builder.vo.PubDataRecord;
import com.huigou.uasp.data.application.DataRecordApplication;
import com.huigou.uasp.data.domain.query.DataRecordQueryRequest;
import com.huigou.uasp.form.application.CommonUtilApplication;
import com.huigou.uasp.model.domain.query.DbTablesQueryRequest;
import com.huigou.uasp.util.ComUtils;
import com.huigou.uasp.util.ReflectionUtil;
import com.huigou.uasp.util.Utils;
import com.huigou.util.ApplicationContextWrapper;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.sql.CallableStatement;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;

@Service("dataRecordApplication")
public class DataRecordApplicationImpl extends BaseApplication implements DataRecordApplication {
   static String QUERY_XML_FILE_PATH = "config/formdesign/dataRecord.xml";
   @Autowired
   private CommonUtilApplication commonUtilApplication;

   private QueryDescriptor getQueryDescriptor(String queryName) {
      if ("".equals(queryName)) {
         queryName = "queryHiddenFieldBySearchSQL";
      }

      return this.sqlExecutorDao.getQuery(QUERY_XML_FILE_PATH, queryName);
   }

   public PubDataRecord loadDataRecord(DataRecordQueryRequest queryRequest) {
      Assert.hasText(queryRequest.getId(), "ID不能为空。");
      List<Map<String, Object>> lists = this.commonUtilApplication.queryDataRecordSingleFields(queryRequest.getFormId(), queryRequest.getMaiTab().toUpperCase());
      String fields = "";
      String[] dataTypes = new String[lists.size()];
      Map<String, Object> map = null;

      for(int i = 0; i < lists.size(); ++i) {
         map = (Map)lists.get(i);
         fields = fields + map.get("fieldCode").toString();
         dataTypes[i] = map.get("fieldType").toString();
         if (i < lists.size() - 1) {
            fields = fields + ",";
         }
      }

      PubDataRecord entity = new PubDataRecord();
      entity.setId(queryRequest.getId());
      DbTablesQueryRequest dbQueryRequest = new DbTablesQueryRequest();
      dbQueryRequest.setTableName(queryRequest.getMaiTab().toUpperCase());
      List<String> hiddenFields = this.commonUtilApplication.queryTableHiddenFields(dbQueryRequest, 0);
      String hiddenCols = StringUtils.join(hiddenFields.toArray(), ",");
      StringBuffer sb = new StringBuffer("");
      sb.append("select  ").append(fields).append(",").append(hiddenCols);
      sb.append(" from ");
      sb.append(queryRequest.getMaiTab());
      sb.append(" t where 1=1 ");
      sb.append(" and t.id='").append(queryRequest.getId()).append("'");
      List<?> dataList = this.generalRepository.queryByNativeSql(sb.toString(), new HashMap());
      Object[] obj = (Object[])dataList.get(0);
      Class<?> clz = entity.getClass();
      Field[] field = clz.getDeclaredFields();
      Map<String, Object> hiMap = new HashMap();

      for(int i = 0; i < obj.length - hiddenFields.size(); ++i) {
         if (obj[i] != null) {
            ReflectionUtil.invokeSet(entity, field[i].getName(), obj[i].toString());
         }
      }

      String[] hiddenCol = hiddenCols.split(",");
      int u = 0;

      for(int j = obj.length - hiddenFields.size(); j < obj.length; ++j) {
         if (obj[j] != null) {
            hiddenCol[u] = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, hiddenCol[u]);
            hiMap.put(hiddenCol[u], obj[j].toString());
         }

         ++u;
      }

      entity.setHiddField(hiMap);
      return entity;
   }

   public PubDataRecord loadDataRecordByAdded(DataRecordQueryRequest queryRequest) {
      PubDataRecord entity = new PubDataRecord();

      try {
         String tableName = queryRequest.getMaiTab();
         queryRequest.setSubTab(tableName);
         new HashMap();
         entity.setFormId(queryRequest.getFormId());
         List<Map<String, Object>> fieldList = this.commonUtilApplication.queryDataRecordSingleFields(queryRequest.getFormId(), tableName.toUpperCase());

         for(int i = 0; i < fieldList.size(); ++i) {
            Map<String, Object> map = (Map)fieldList.get(i);
            if (map.get("codeRuleId") != null && !"".equals(map.get("codeRuleId").toString())) {
               Object codeGenerator = ApplicationContextWrapper.getBean("codeGenerator");
               Method method = codeGenerator.getClass().getMethod("getNextCode", String.class);
               String code = (String)method.invoke(codeGenerator, map.get("codeRuleId").toString());
               ReflectionUtil.invokeSet(entity, "field" + i, code);
            }
         }

         return entity;
      } catch (Exception var10) {
         throw new IllegalArgumentException(var10.getMessage());
      }
   }

   public Map<String, Object> queryDataRecord(DataRecordQueryRequest queryRequest) {
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptor(""), queryRequest);
      new HashMap();
      List<Map<String, Object>> fieldList = this.commonUtilApplication.queryDataRecordSingleFields(queryRequest.getFormId(), queryRequest.getMaiTab().toUpperCase());
      String fields = "";
      if ("all".equals(queryModel.getExportType())) {
         fields = Utils.getDataFieldsByAlias(fieldList);
      } else {
         fields = Utils.getDataFields(fieldList, "fieldCode");
      }

      StringBuffer sb = new StringBuffer("");
      String searchFields;
      if (!"".equals(fields)) {
         sb.append("select  id,form_id,");
         sb.append(fields);
         sb.append(",'' sequence,status,created_date from ");
         sb.append(queryRequest.getMaiTab());
         sb.append(" where 1=1 ");
         Map<String, Object> map = queryRequest.getSearchContent();
         if (!map.isEmpty()) {
            searchFields = Utils.getSearchDataFields(fieldList);
            if (!"".equals(searchFields)) {
               String[] searchField = searchFields.split(",");

               for(int u = 0; u < searchField.length; ++u) {
                  if (map.get("field" + u) != null && !"".equals(map.get("field" + u).toString())) {
                     String value = map.get("field" + u).toString();
                     sb.append(" and ");
                     sb.append(searchField[u]).append(" like '%").append(value).append("%'");
                  }
               }
            }
         }
      } else {
         sb.append("select t.id,t.classify_id,'' model_id,'' sequence,created_date from mdm_model_record t where 1=2");
      }

      if (queryModel.getSortFieldName().startsWith("field")) {
         String[] field = fields.split(",");
         searchFields = queryModel.getSortFieldName();
         queryModel.setSortFieldName(field[Integer.parseInt(searchFields.substring(5))]);
      } else {
         queryModel.setSortFieldName("created_date");
         queryModel.setSortOrder("desc");
      }

      queryModel.setSql(sb.toString());
      Map mapData;
      if ("all".equals(queryModel.getExportType())) {
         mapData = this.sqlExecutorDao.executeSlicedQuery(queryModel);
      } else {
         mapData = this.sqlExecutorDao.executeSlicedQuery(queryModel);
         mapData.put("Rows", Utils.dataFieldTransfer(fieldList, (List)mapData.get("Rows")));
      }

      return mapData;
   }

   @Transactional
   public List<PubDataRecord> saveDataRecord(DataRecordQueryRequest queryRequest, List<Map<String, Object>> dataList) {
      List<PubDataRecord> backlist = new ArrayList();
      PubDataRecord entity = null;

      try {
         List<Map<String, Object>> fieldList = this.commonUtilApplication.queryDataRecordSingleFields(queryRequest.getFormId(), queryRequest.getMaiTab().toUpperCase());
         Operator operator = ThreadLocalUtil.getOperator();
         new ArrayList();
         String tableName = queryRequest.getMaiTab();
         List<String> hiddenFields = queryRequest.getHiddenField();
         String hiddeCols = StringUtils.join(hiddenFields.toArray(), ",");
         boolean isAdded = false;

         for(Iterator var13 = dataList.iterator(); var13.hasNext(); backlist.add(entity)) {
            Map<String, Object> map = (Map)var13.next();
            isAdded = false;
            entity = new PubDataRecord();
            String columns = Utils.getDataFields(fieldList, "fieldCode");
            String hiddMap;
            if (org.springframework.util.StringUtils.isEmpty(map.get("id"))) {
               hiddMap = Utils.createUuid();
               isAdded = true;
               map.put("id", hiddMap);
               entity.setId(hiddMap);
               if (hiddenFields.contains("created_date")) {
                  map.put("created_date", "sysdate");
               }

               if (hiddenFields.contains("status")) {
                  map.put("status", 1);
               }
            } else {
               entity.setId(map.get("id").toString());
               if (hiddenFields.contains("created_date")) {
                  hiddMap = this.commonUtilApplication.queryDBCurrentDate();
                  map.put("created_date", hiddMap);
               }
            }

            if (hiddenFields.contains("created_by_id")) {
               map.put("created_by_id", operator.getPersonMemberId());
            }

            if (hiddenFields.contains("created_by_name")) {
               map.put("created_by_name", operator.getPersonMemberName());
            }

            map.put("form_id", queryRequest.getFormId());
            List<Map<String, Object>> datas = new ArrayList();
            datas.add(map);

            for(int i = 0; i < datas.size(); ++i) {
               ((Map)datas.get(i)).put("seqVal", String.format("%03d", i));
            }

            if (isAdded) {
               hiddMap = ComUtils.getMultiInsertSqlByList(tableName, datas, columns + "," + hiddeCols);
               this.sqlExecutorDao.executeUpdate(hiddMap, new Object[0]);
            } else {
               hiddMap = null;
               Iterator var17 = hiddenFields.iterator();

               String hiddField;
               while(var17.hasNext()) {
                  hiddField = (String)var17.next();
                  if (!"id".equals(hiddField) && !"form_id".equals(hiddField)) {
                     columns = columns + "," + hiddField;
                     Map<String, Object> hashMap = new HashMap();
                     hashMap.put("fieldCode", hiddField);
                     if ("created_date".equals(hiddField)) {
                        hashMap.put("fieldType", "date");
                     } else {
                        hashMap.put("fieldType", "string");
                     }

                     fieldList.add(hashMap);
                  }
               }

               hiddField = String.format("update %s set %s where id = ?", tableName, ComUtils.getMultiUpdateColumnSqlByList(fieldList, columns));
               this.sqlExecutorDao.batchUpdate(hiddField, ComUtils.convertListMapToListObjects(datas, columns + ",id"));
            }
         }

         return backlist;
      } catch (Exception var18) {
         var18.printStackTrace();
         throw new IllegalArgumentException(var18.getMessage());
      }
   }

   @Transactional
   public void deleteDataRecord(DataRecordQueryRequest queryRequest, List<String> ids) {
      String tableName = queryRequest.getMaiTab();

      try {
         StringBuffer sb = null;
         StringBuffer detailsb = null;
         String[] detailTables = null;

         for(int u = 0; u < ids.size(); ++u) {
            sb = new StringBuffer();
            if (!org.springframework.util.StringUtils.isEmpty(ids.get(u))) {
               sb.append("delete from ").append(tableName).append(" where id='").append((String)ids.get(u)).append("'");
               detailTables = queryRequest.getSubTab().split(",");

               for(int i = 0; i < detailTables.length; ++i) {
                  detailsb = new StringBuffer("");
                  detailsb.append("delete from ").append(detailTables[i]).append(" where parent_id='").append((String)ids.get(u)).append("'");
                  this.sqlExecutorDao.executeUpdate(detailsb.toString(), new Object[0]);
               }

               this.sqlExecutorDao.executeUpdate(sb.toString(), new Object[0]);
            }
         }
      } catch (Exception var9) {
         var9.printStackTrace();
      }

   }

   public int queryIsExistTable(DataRecordQueryRequest queryRequest) {
      String detailTableName = queryRequest.getSubTab();
      QueryDescriptor queryDescriptor = this.sqlExecutorDao.getQuery(QUERY_XML_FILE_PATH, "currentExistTable");
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(queryDescriptor, queryRequest);
      String sql = queryModel.getSql() + " and t.table_name='" + detailTableName.toUpperCase() + "'";
      queryModel.setSql(sql);
      queryModel.setSortFieldName("sequence");
      Map<String, Object> mapData = this.sqlExecutorDao.executeSlicedQuery(queryModel);
      int total = 0;
      if (mapData.get("file") != null) {
         total = 1;
      } else {
         total = Integer.parseInt(mapData.get("Total").toString());
      }

      return total;
   }

   public Map<String, Object> queryDataRecordDetail(DataRecordQueryRequest queryRequest) {
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptor(""), queryRequest);
      List<Map<String, Object>> fieldList = this.commonUtilApplication.queryDataRecordMultsFields(queryRequest.getFormId(), queryRequest.getSubTab().toUpperCase());
      String detailTableName = queryRequest.getSubTab();
      String fields = Utils.getDataFields(fieldList, "fieldCode");
      String hiddFields = queryRequest.getHiddenField().toString();
      StringBuffer sb = new StringBuffer("");
      sb.append("select  id,parent_id,");
      if (queryRequest.getHiddenField().size() > 0) {
         sb.append(hiddFields.substring(1, hiddFields.length() - 1)).append(",");
      }

      sb.append(fields);
      sb.append(",'' sequence,status  from ");
      sb.append(detailTableName);
      sb.append(" where 1=1 ");
      if (queryRequest.getId() != null) {
         sb.append(" and parent_id='").append(queryRequest.getId()).append("'");
      }

      if (queryModel.getSortFieldName().startsWith("field")) {
         String[] field = fields.split(",");
         queryModel.setSortFieldName(field[Integer.parseInt(queryModel.getSortFieldName().substring(5))]);
      }

      queryModel.setSql(sb.toString());
      Map<String, Object> mapData = this.sqlExecutorDao.executeSlicedQuery(queryModel);
      mapData.put("Rows", Utils.dataFieldTransfer(fieldList, (List)mapData.get("Rows")));
      return mapData;
   }

   @Transactional
   public String saveDataRecordDetail(DataRecordQueryRequest queryRequest, List<String> hiddenFieldList, List<PubDataRecord> detailData) {
      Assert.hasText(queryRequest.getId(), "ID不能为空。");
      String maiTable = CaseFormat.UPPER_CAMEL.to(CaseFormat.LOWER_UNDERSCORE, queryRequest.getMaiTab());
      String subTable = CaseFormat.UPPER_CAMEL.to(CaseFormat.LOWER_UNDERSCORE, queryRequest.getSubTab());
      String sql = "";
      String backStr = "success";

      try {
         queryRequest.setMaiTab(maiTable);
         queryRequest.setSubTab(subTable);
         Operator operator = ThreadLocalUtil.getOperator();
         List<Map<String, Object>> fieldList = this.commonUtilApplication.queryDataRecordMultsFields(queryRequest.getFormId(), queryRequest.getSubTab().toUpperCase());
         Map<String, Object> map = null;
         new ArrayList();
         String parentId = queryRequest.getId();
         String columns = Utils.getDataFields(fieldList, "fieldCode");
         new HashMap();
         Iterator var16 = hiddenFieldList.iterator();

         String dbrq;
         while(var16.hasNext()) {
            dbrq = (String)var16.next();
            if (!"id".equals(dbrq)) {
               columns = columns + "," + dbrq;
               Map<String, Object> hiddMap = new HashMap();
               hiddMap.put("fieldCode", dbrq);
               if ("created_date".equals(dbrq)) {
                  hiddMap.put("fieldType", "date");
               } else {
                  hiddMap.put("fieldType", "string");
               }

               fieldList.add(hiddMap);
            }
         }

         dbrq = this.commonUtilApplication.queryDBCurrentDate();
         Iterator var17 = detailData.iterator();

         while(var17.hasNext()) {
            PubDataRecord detail = (PubDataRecord)var17.next();
            map = Utils.dataValueTransfer(fieldList, detail);
            map.putAll(detail.getHiddField());
            List<Map<String, Object>> datas = new ArrayList();
            if (hiddenFieldList.contains("created_date")) {
               map.put("created_date", dbrq);
            }

            if (hiddenFieldList.contains("created_by_id")) {
               map.put("created_by_id", operator.getPersonMemberId());
            }

            if (hiddenFieldList.contains("created_by_name")) {
               map.put("created_by_name", operator.getPersonMemberName());
            }

            if (!org.springframework.util.StringUtils.isEmpty(detail.getId())) {
               map.put("id", detail.getId());
               datas.add(map);
               sql = String.format("update %s set %s where id = ?", subTable, ComUtils.getMultiUpdateColumnSqlByList(fieldList, columns));
               this.sqlExecutorDao.batchUpdate(sql, ComUtils.convertListMapToListObjects(datas, columns + ",id"));
            } else {
               map.put("parent_id", parentId);
               map.put("status", 1);
               datas.add(map);
               sql = ComUtils.getMultiInsertSqlByList(subTable, datas, columns + ",status,id,parent_id");
               this.sqlExecutorDao.executeUpdate(sql, new Object[0]);
            }
         }

         return backStr;
      } catch (Exception var18) {
         System.out.println("sql:=" + sql);
         backStr = "failure";
         throw new ApplicationException("保存明细表数据错误：" + var18.getMessage());
      }
   }

   public List<Map<String, Object>> queryHiddenFieldBySearchSQL(DataRecordQueryRequest queryRequest) {
      new HashMap();
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptor("queryHiddenFieldBySearchSQL"), queryRequest);
      String sql = queryModel.getSql();
      if (queryRequest.getSubTab() != null && !"".equals(queryRequest.getSubTab())) {
         sql = sql + " and t.table_name='" + CaseFormat.UPPER_CAMEL.to(CaseFormat.LOWER_UNDERSCORE, queryRequest.getSubTab()).toUpperCase() + "'";
      }

      queryModel.setSql(sql);
      Map<String, Object> mapData = this.sqlExecutorDao.executeSlicedQuery(queryModel);
      List<Map<String, Object>> list = (List)mapData.get("Rows");
      return list;
   }

   @Transactional
   public void deleteDataRecordDetail(DataRecordQueryRequest queryRequest, String ids) {
      Assert.hasText(queryRequest.getId(), "ID不能为空。");
      String tableName = CaseFormat.UPPER_CAMEL.to(CaseFormat.LOWER_UNDERSCORE, queryRequest.getSubTab());

      try {
         StringBuffer sb = null;
         String[] id = ids.split(",");

         for(int u = 0; u < id.length; ++u) {
            sb = new StringBuffer();
            if (!org.springframework.util.StringUtils.isEmpty(id[u])) {
               sb.append("delete from ").append(tableName).append(" where id='").append(id[u]).append("'");
               this.sqlExecutorDao.executeUpdate(sb.toString(), new Object[0]);
            }
         }
      } catch (Exception var7) {
         var7.printStackTrace();
      }

   }

   public String changeDataRecordStatus(DataRecordQueryRequest queryRequest) {
      String backStr = "";
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptor(""), queryRequest);
      String tableName = queryRequest.getMaiTab();
      Map<String, Object> mapData = new HashMap();
      if (!org.springframework.util.StringUtils.isEmpty(queryRequest.getId())) {
         List<Map<String, Object>> datas = new ArrayList();
         mapData.put("id", queryRequest.getId());
         mapData.put("status", queryRequest.getStatus());
         datas.add(mapData);
         String batchUpdateSql = String.format("update " + tableName + " set status=? where id = ?");
         String columns = "status,id";
         this.sqlExecutorDao.batchUpdate(batchUpdateSql, ComUtils.convertListMapToListObjects(datas, columns));
      }

      return backStr;
   }

   public String changeDataRecordDetailStatus(DataRecordQueryRequest queryRequest) {
      String backStr = "";
      String tableName = CaseFormat.UPPER_CAMEL.to(CaseFormat.LOWER_UNDERSCORE, queryRequest.getSubTab());
      Map<String, Object> mapData = new HashMap();
      if (!org.springframework.util.StringUtils.isEmpty(queryRequest.getId())) {
         List<Map<String, Object>> datas = new ArrayList();
         mapData.put("id", queryRequest.getId());
         mapData.put("status", queryRequest.getStatus());
         datas.add(mapData);
         String batchUpdateSql = String.format("update " + tableName + " set status=? where id = ?");
         String columns = "status,id";
         this.sqlExecutorDao.batchUpdate(batchUpdateSql, ComUtils.convertListMapToListObjects(datas, columns));
      }

      return backStr;
   }

   public String checkFieldFunction(Map<String, Object> map) {
      Connection conn = null;
      CallableStatement stmt = null;
      String backMsg = "";

      try {
         conn = this.sqlExecutorDao.getDataSource().getConnection();
         String currVal = map.get("currVal").toString();
         String funcname = map.get("funcname").toString();
         String[] paramfield = null;
         if (map.get("paramfields") != null) {
            String paramfields = map.get("paramfields").toString();
            paramfield = paramfields.split(",");
         }

         StringBuffer callFunc = new StringBuffer("");
         callFunc.append("{?=call ").append(funcname);
         callFunc.append("(?,?");
         int x;
         if (paramfield != null) {
            for(x = 0; x < paramfield.length; ++x) {
               callFunc.append(",?");
            }
         }

         callFunc.append(")}");
         stmt = conn.prepareCall(callFunc.toString());
         stmt.registerOutParameter(1, 12);
         stmt.setString(2, map.get("id").toString());
         stmt.setString(3, currVal);

         for(x = 0; x < paramfield.length; ++x) {
            stmt.setString(x + 4, map.get(paramfield[x]).toString());
         }

         stmt.executeUpdate();
         backMsg = stmt.getString(1) != null ? stmt.getString(1) : "";
      } catch (Exception var18) {
         backMsg = var18.getMessage();
         var18.printStackTrace();
      } finally {
         try {
            stmt.close();
            if (conn != null) {
               conn.close();
            }
         } catch (SQLException var17) {
            var17.printStackTrace();
         }

      }

      return backMsg;
   }
}
