package com.huigou.uasp.form.application.impl;

import com.google.common.base.CaseFormat;
import com.huigou.data.query.model.QueryDescriptor;
import com.huigou.data.query.model.QueryModel;
import com.huigou.uasp.bmp.common.application.BaseApplication;
import com.huigou.uasp.builder.vo.SeleListCustomVO;
import com.huigou.uasp.form.application.CommonUtilApplication;
import com.huigou.uasp.form.domain.model.FormSearchSql;
import com.huigou.uasp.form.domain.model.FormTables;
import com.huigou.uasp.form.domain.query.SafFormsQueryRequest;
import com.huigou.uasp.form.repository.FormSearchSqlRepository;
import com.huigou.uasp.form.repository.FormTablesRepository;
import com.huigou.uasp.model.domain.query.DbTablesQueryRequest;
import com.huigou.uasp.model.repository.DbTablesRepository;
import com.huigou.uasp.util.Utils;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service("commonUtilApplication")
public class CommonUtilApplicationImpl extends BaseApplication implements CommonUtilApplication {
   @Autowired
   private FormTablesRepository formTablesRepository;
   @Autowired
   private DbTablesRepository dbTablesRepository;
   @Autowired
   private FormSearchSqlRepository formSearchSqlRepository;

   private QueryDescriptor getQueryDescriptor(String queryName) {
      return this.sqlExecutorDao.getQuery("config/formdesign/safFormslist.xml", queryName);
   }

   private QueryDescriptor getQueryDescriptorTables(String queryName) {
      return this.sqlExecutorDao.getQuery("config/formdesign/dbtables.xml", queryName);
   }

   public String queryDBCurrentDate() {
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptorTables("queryDefaultDate"), new DbTablesQueryRequest());
      List<?> rqList = this.generalRepository.queryByNativeSql(queryModel.getSql(), new HashMap());
      return rqList.get(0).toString().substring(0, 19);
   }

   public String getTablesByFormId(String formId, int tableType) {
      List<FormTables> tableList = this.formTablesRepository.findByFormId(formId);
      String tableName = "";
      Iterator var6 = tableList.iterator();

      while(var6.hasNext()) {
         FormTables table = (FormTables)var6.next();
         if (!"".equals(tableName)) {
            tableName = tableName + ",";
         }

         if (tableType == 0) {
            tableName = tableName + table.getTableName();
         } else if (tableType == 1) {
            if (table.getTableType() == 1) {
               tableName = tableName + table.getTableName();
            }
         } else if (tableType == 2 && table.getTableType() == 2) {
            tableName = tableName + table.getTableName();
         }
      }

      tableName = tableName.toLowerCase();
      return tableName;
   }

   public List<Map<String, Object>> queryDataRecordSingleFields(String formId, String tableName) {
      new HashMap();
      SafFormsQueryRequest queryRequest = new SafFormsQueryRequest();
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptor("queryFormDataRecordFields"), queryRequest);
      queryModel.setPageSize(101);
      queryModel.setPageIndex(1);
      String sql = queryModel.getSql();
      new StringBuffer("");
      sql = sql + " and a.form_id='" + formId + "'";
      if (tableName.indexOf(",") > 0) {
         String[] tables = tableName.split(",");
         tableName = "";

         for(int u = 0; u < tables.length; ++u) {
            tableName = tableName + "'" + tables[u] + "'";
            if (u < tables.length - 1) {
               tableName = tableName + ",";
            }
         }

         sql = sql + " and a.table_name in (" + tableName + ")";
      } else {
         sql = sql + " and a.table_name='" + tableName + "'";
      }

      sql = sql + " order by a.table_type,a.sequence ";
      queryModel.setSortFieldName("sequence");
      queryModel.setSql(sql);
      if ("all".equals(queryModel.getExportType())) {
         queryModel.setExportType((String)null);
      }

      Map<String, Object> mapData = this.sqlExecutorDao.executeSlicedQuery(queryModel);
      List<Map<String, Object>> list = (List)mapData.get("Rows");
      return list;
   }

   public List<Map<String, Object>> queryDataRecordMultsFields(String formId, String tableName) {
      new HashMap();
      SafFormsQueryRequest queryRequest = new SafFormsQueryRequest();
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptor("queryFormDataRecordFields"), queryRequest);
      queryModel.setPageSize(101);
      queryModel.setPageIndex(1);
      String sql = queryModel.getSql();
      StringBuffer sb = new StringBuffer(sql);
      sb.append(" and a.table_type=2 ");
      sb.append(" and a.form_id='").append(formId).append("'");
      sb.append(" and a.table_name='").append(tableName).append("'");
      sb.append(" order by a.sequence ");
      queryModel.setSortFieldName("sequence");
      queryModel.setSql(sb.toString());
      Map<String, Object> mapData = this.sqlExecutorDao.executeSlicedQuery(queryModel);
      List<Map<String, Object>> list = (List)mapData.get("Rows");
      return list;
   }

   public List<Map<String, Object>> queryFormTableFields(String formNo, String tableName) {
      new HashMap();
      SafFormsQueryRequest queryRequest = new SafFormsQueryRequest();
      queryRequest.setFormNo(formNo);
      queryRequest.setTableName(tableName.toUpperCase());
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptor("queryFormTableFields"), queryRequest);
      queryModel.setPageSize(101);
      queryModel.setPageIndex(1);
      queryModel.setSortFieldName("nums");
      Map<String, Object> mapData = this.sqlExecutorDao.executeSlicedQuery(queryModel);
      List<Map<String, Object>> list = (List)mapData.get("Rows");
      return list;
   }

   public List<String> queryTableHiddenFields(DbTablesQueryRequest queryRequest, int toCamel) {
      queryRequest.setIsHidden(1);
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptorTables("dbTableFields"), queryRequest);
      queryModel.setPageSize(101);
      queryModel.setPageIndex(1);
      Map<String, Object> mapData = this.sqlExecutorDao.executeSlicedQuery(queryModel);
      List<Map<String, Object>> list = (List)mapData.get("Rows");
      List<String> slist = new ArrayList();
      String hiddenField = "";

      for(Iterator var9 = list.iterator(); var9.hasNext(); slist.add(hiddenField)) {
         Map<String, Object> map = (Map)var9.next();
         hiddenField = map.get("fieldCode").toString();
         if (toCamel == 1) {
            hiddenField = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, hiddenField);
         }
      }

      return slist;
   }

   public List<String> querySearchSQLHiddenFields(String formNo) {
      List<FormSearchSql> customlists = this.formSearchSqlRepository.searchSqlByFormNo(formNo);
      SeleListCustomVO customVO = null;
      Map<String, Object> map = null;
      List<String> hiddenFields = new ArrayList();

      for(int i = 0; i < customlists.size(); ++i) {
         customVO = new SeleListCustomVO();
         Utils.CopyBean(customlists.get(i), customVO);
         hiddenFields.addAll(Utils.getHiddenFields(customVO));
      }

      return hiddenFields;
   }
}
