package com.huigou.uasp.form.application.impl;

import com.alibaba.fastjson.JSONObject;
import com.huigou.data.query.model.QueryDescriptor;
import com.huigou.data.repository.GeneralRepository;
import com.huigou.uasp.bmp.common.application.BaseApplication;
import com.huigou.uasp.bmp.configuration.repository.SysDictionaryRepository;
import com.huigou.uasp.form.application.CommonUtilApplication;
import com.huigou.uasp.form.application.FormsDesignApplication;
import com.huigou.uasp.form.domain.model.FormAttribute;
import com.huigou.uasp.form.domain.model.FormSearchSql;
import com.huigou.uasp.form.domain.model.SafFormslist;
import com.huigou.uasp.form.domain.query.FormsAttributeQueryRequest;
import com.huigou.uasp.form.pojo.Options;
import com.huigou.uasp.form.pojo.PubProperty;
import com.huigou.uasp.form.pojo.Root;
import com.huigou.uasp.form.pojo.TableColumns;
import com.huigou.uasp.form.repository.FormAttributeRepository;
import com.huigou.uasp.form.repository.FormSearchSqlRepository;
import com.huigou.uasp.form.repository.SafFormslistRepository;
import com.huigou.uasp.util.Utils;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import net.sf.ezmorph.bean.MorphDynaBean;
import org.apache.commons.beanutils.DynaProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service("formsDesignApplication")
public class FormsDesignApplicationImpl extends BaseApplication implements FormsDesignApplication {
   static String QUERY_XML_FILE_PATH = "config/formdesign/safFormslist.xml";
   private String pagePath = "/customform/";
   @Autowired
   private GeneralRepository generalRepository;
   @Autowired
   private SafFormslistRepository safFormslistRepository;
   @Autowired
   private FormAttributeRepository formAttributeRepository;
   @Autowired
   private FormSearchSqlRepository formSearchSqlRepository;
   @Autowired
   private SysDictionaryRepository sysDictionaryRepository;
   @Autowired
   private CommonUtilApplication commonUtilApplication;

   private QueryDescriptor getQueryDescriptor(String entityName) {
      return this.sqlExecutorDao.getQuery(QUERY_XML_FILE_PATH, entityName);
   }

   @Transactional
   public Map<String, Object> saveFormAttribute(FormsAttributeQueryRequest queryRequest, SafFormslist form) {
      Map<String, Object> map = new HashMap();
      ((Map)map).put("success", "1");

      try {
         List<Root> rootList = queryRequest.getRootList();
         String mainTableName = queryRequest.getTableName();
         form.setJson(queryRequest.getJson());
         this.safFormslistRepository.saveAndFlush(form);
         this.formAttributeRepository.deleteFormAttributeByFormIdAndTableName(form.getId(), mainTableName);
         List<Map<String, Object>> mainFieldLists = this.commonUtilApplication.queryFormTableFields(queryRequest.getFormNo(), mainTableName);
         int sequence = 0;
         Iterator var9 = rootList.iterator();

         while(var9.hasNext()) {
            Root root = (Root)var9.next();
            root.setFormId(form.getId());
            root.setFormNo(form.getFormNo());
            if ("table".equals(root.getType())) {
               map = this.saveTableAttribute(root);
            } else {
               map = this.saveFormAttribute(root, mainFieldLists, sequence);
               sequence = Integer.parseInt(((Map)map).get("sequence").toString());
            }
         }
      } catch (Exception var10) {
         ((Map)map).put("success", "0");
         ((Map)map).put("reason", var10.getMessage());
         var10.printStackTrace();
      }

      return (Map)map;
   }

   private Map<String, Object> saveFormAttribute(Root root, List<Map<String, Object>> fieldLists, int sequence) {
      Map<String, Object> map = new HashMap();
      ((Map)map).put("success", "1");
      ((Map)map).put("reason", "");
      List<TableColumns> tableList = root.getTableColumns();
      int tableType = 1;
      PubProperty property = null;

      try {
         if (tableList == null) {
            ++sequence;
            property = new PubProperty();
            Utils.CopyBean(root, property);
            map = this.saveAttributeDetail(property, fieldLists, tableType, sequence);
         } else {
            for(Iterator var9 = tableList.iterator(); var9.hasNext(); map = this.saveAttributeDetail(property, fieldLists, tableType, sequence)) {
               TableColumns tableColumns = (TableColumns)var9.next();
               ++sequence;
               property = new PubProperty();
               Utils.CopyBean(tableColumns, property);
               property.setFormId(root.getFormId());
               property.setFormNo(root.getFormNo());
            }
         }

         ((Map)map).put("sequence", sequence);
      } catch (Exception var10) {
         ((Map)map).put("success", "0");
         ((Map)map).put("reason", var10.getMessage());
         var10.printStackTrace();
      }

      return (Map)map;
   }

   private Map<String, Object> saveTableAttribute(Root root) {
      Map<String, Object> map = new HashMap();
      ((Map)map).put("success", "1");
      ((Map)map).put("reason", "");
      List<TableColumns> tableList = root.getTableColumns();
      List<Map<String, Object>> fieldLists = new ArrayList();
      int tableType = 2;
      int s = 0;

      try {
         PubProperty property = null;
         if (tableList != null && tableList.size() > 0) {
            if (((TableColumns)tableList.get(0)).getTable() != null) {
               fieldLists = this.commonUtilApplication.queryFormTableFields(root.getFormNo(), ((TableColumns)tableList.get(0)).getTable());
            }

            this.formAttributeRepository.deleteFormAttributeByFormIdAndTableName(root.getFormId(), ((TableColumns)tableList.get(0)).getTable());
         }

         for(Iterator var9 = tableList.iterator(); var9.hasNext(); ++s) {
            TableColumns tableColumns = (TableColumns)var9.next();
            property = new PubProperty();
            Utils.CopyBean(tableColumns, property);
            property.setFormId(root.getFormId());
            property.setFormNo(root.getFormNo());
            map = this.saveAttributeDetail(property, (List)fieldLists, tableType, s);
         }
      } catch (Exception var10) {
         ((Map)map).put("success", "0");
         ((Map)map).put("reason", var10.getMessage());
         var10.printStackTrace();
      }

      return (Map)map;
   }

   private Map<String, Object> saveAttributeDetail(PubProperty root, List<Map<String, Object>> fieldLists, int tableType, int sequence) {
      Map<String, Object> map = new HashMap();
      map.put("success", "1");
      String reason = "";

      try {
         FormAttribute formAttribute = new FormAttribute();
         formAttribute.setId(Utils.createUuid());
         formAttribute.setFormId(root.getFormId());
         formAttribute.setTableName(root.getTable());
         formAttribute.setTableType(tableType);
         formAttribute.setAttrCode(root.getModel());
         formAttribute.setAttrName(root.getName());
         Map<String, Object> fieldMap = null;
         String metaId = "";

         for(int x = 0; x < fieldLists.size(); ++x) {
            fieldMap = (Map)fieldLists.get(x);
            if (root.getModel().equals(fieldMap.get("fieldCode").toString())) {
               metaId = fieldMap.get("id").toString();
               break;
            }
         }

         formAttribute.setMetaId(metaId);
         if (root.getOptions().getFormat() != null) {
            if ("date".equals(root.getType())) {
               formAttribute.setDataFormat(root.getType());
            } else {
               formAttribute.setDataFormat(root.getOptions().getFormat());
            }
         } else {
            formAttribute.setDataFormat("string");
         }

         formAttribute.setStatus(1);
         formAttribute.setFieldTag(root.getType());
         if ("input".equals(root.getType())) {
            formAttribute.setFieldTag("text");
         }

         String dataSourceType;
         if ("select".equals(root.getType())) {
            dataSourceType = "1";
            if (root.getOptions().getDataType() != null && !"".equals(root.getOptions().getDataType())) {
               dataSourceType = root.getOptions().getDataType();
            }

            formAttribute.setDataSourceType(dataSourceType);
         }

         List optionbeans;
         DynaProperty[] tabdynaProperties;
         JSONObject backData;
         String key;
         if ("checkbox".equals(root.getType()) || "radio".equals(root.getType())) {
            dataSourceType = "4";
            if (root.getOptions().getDictionary() != null && !"".equals(root.getOptions().getDictionary())) {
               dataSourceType = "3";
               formAttribute.setDataSource(root.getOptions().getDictionary());
            } else {
               optionbeans = root.getOptions().getOptions();
               tabdynaProperties = null;
               backData = new JSONObject();
               key = "";
               String val = "";
               Object attrVal = null;
               String attrName = "";
               int k = 1;

               for(Iterator var20 = optionbeans.iterator(); var20.hasNext(); ++k) {
                  MorphDynaBean tbeans = (MorphDynaBean)var20.next();
                  tabdynaProperties = tbeans.getDynaClass().getDynaProperties();

                  for(int m = 0; m < tabdynaProperties.length; ++m) {
                     attrName = tabdynaProperties[m].getName();
                     attrVal = tbeans.get(attrName);
                     System.out.println(attrName + "===attrVal====" + attrVal.toString().trim());
                     if (attrVal != null) {
                        if ("label".equals(attrName)) {
                           key = attrVal.toString().trim();
                        } else {
                           val = attrVal.toString().trim();
                        }
                     }
                  }

                  if ("".equals(key)) {
                     key = String.valueOf(k);
                  }

                  backData.put(key, val);
               }

               formAttribute.setDataSource(backData.toJSONString());
            }

            formAttribute.setDataSourceType(dataSourceType);
         }

         if ("easy_search".equals(root.getType())) {
            Options option = root.getOptions();
            optionbeans = option.getOptions();
            tabdynaProperties = null;
            backData = null;
            key = "";
            MorphDynaBean tabbean = (MorphDynaBean)optionbeans.get(1);
            tabdynaProperties = tabbean.getDynaClass().getDynaProperties();
            key = tabdynaProperties[0].getName();
            tabbean.get(key);
            List<MorphDynaBean> querybeans = (List)tabbean.get(key);
            Object attrVal = ((MorphDynaBean)querybeans.get(0)).get("queryName");
            formAttribute.setDataSource(attrVal.toString());
            formAttribute.setDataSourceType("2");
            formAttribute.setFieldTag("select");
            List<FormSearchSql> slist = this.formSearchSqlRepository.searchSqlByFormNoAndSearchName(root.getFormNo(), attrVal.toString());
            if (slist != null && slist.size() > 0) {
               FormSearchSql formSearchSql = (FormSearchSql)slist.get(0);
               formSearchSql.setTargetField(root.getModel());
               formSearchSql.setTableName(root.getTable());
               formSearchSql.setCreatedDate(new Date());
               this.formSearchSqlRepository.saveAndFlush(formSearchSql);
            }
         }

         if (root.getOptions().getCustomClass() != null) {
            formAttribute.setCssStyle(root.getOptions().getCustomClass());
         }

         formAttribute.setMustInput(root.getOptions().getRequired() ? 1 : 0);
         if (tableType == 1) {
            formAttribute.setDisplayListing(1);
         }

         formAttribute.setSequence(sequence);
         formAttribute.setCreatedDate(new Date());
         if (!"".equals(metaId)) {
            this.formAttributeRepository.save(formAttribute);
         } else {
            if ("".equals(reason)) {
               reason = "没有找到字段:";
            } else {
               reason = reason + root.getModel() + ",";
            }

            System.out.println("没有找到字段:" + root.getModel());
         }

         map.put("reason", reason);
      } catch (Exception var22) {
         map.put("success", "0");
         map.put("reason", var22.getMessage());
         var22.printStackTrace();
      }

      return map;
   }

   public String getUserDictFolderIds(String dictName) {
      StringBuffer sb = new StringBuffer();
      sb = sb.append("select id from SA_CommonTree t start with name = '").append(dictName).append("' connect by t.parent_id= prior id");
      String sql = sb.toString();
      List<String> ids = this.sqlExecutorDao.queryToList(sql, String.class, (Object[])null);
      String resultIds = String.join(",", ids);
      return resultIds;
   }

   public List<Map<String, Object>> getFormDataDict(String dictName) {
      String folderId = this.getUserDictFolderIds(dictName);
      String sql = "select a.code,a.name from sa_dictionary a where a.folder_id='" + folderId + "'";
      List<Map<String, Object>> data = this.sqlExecutorDao.queryToListMap(sql, (Object[])null);
      return data;
   }

   public List<Map<String, Object>> getDBFunctionsOrProceduce(String type) {
      String sql = this.getQueryDescriptor("queryFormFunctionOrProcduce").getSql();
      return this.sqlExecutorDao.queryToListMap(sql, new Object[]{type});
   }
}
