package com.huigou.uasp.form.application.impl;

import com.google.common.base.CaseFormat;
import com.huigou.data.query.model.QueryDescriptor;
import com.huigou.data.query.model.QueryModel;
import com.huigou.uasp.bmp.common.application.BaseApplication;
import com.huigou.uasp.bmp.opm.domain.model.resource.SysFunction;
import com.huigou.uasp.bmp.opm.proxy.SysFunctionApplicationProxy;
import com.huigou.uasp.bmp.opm.repository.org.SysFunctionRepository;
import com.huigou.uasp.builder.BuildTypeClass;
import com.huigou.uasp.builder.filer.BuildPageDetailFile;
import com.huigou.uasp.builder.vo.ParamFormVO;
import com.huigou.uasp.builder.vo.SeleListCustomVO;
import com.huigou.uasp.form.application.CommonUtilApplication;
import com.huigou.uasp.form.application.SafFormslistApplication;
import com.huigou.uasp.form.domain.model.FormAttribute;
import com.huigou.uasp.form.domain.model.FormButtonVO;
import com.huigou.uasp.form.domain.model.FormButtons;
import com.huigou.uasp.form.domain.model.FormSearchSql;
import com.huigou.uasp.form.domain.model.FormTables;
import com.huigou.uasp.form.domain.model.PropertyDefines;
import com.huigou.uasp.form.domain.model.SafFormslist;
import com.huigou.uasp.form.domain.query.FormParameterQueryRequest;
import com.huigou.uasp.form.domain.query.SafFormsQueryRequest;
import com.huigou.uasp.form.repository.FormAttributeRepository;
import com.huigou.uasp.form.repository.FormButtonsRepository;
import com.huigou.uasp.form.repository.FormSearchSqlRepository;
import com.huigou.uasp.form.repository.FormTablesRepository;
import com.huigou.uasp.form.repository.SafFormslistRepository;
import com.huigou.uasp.meta.domain.model.MetaData;
import com.huigou.uasp.meta.repository.MetaDataRepository;
import com.huigou.uasp.model.domain.query.DbTablesQueryRequest;
import com.huigou.uasp.util.Utils;
import com.huigou.util.StringUtil;
import java.io.File;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;

@Service("safFormslistApplication")
public class SafFormslistApplicationImpl extends BaseApplication implements SafFormslistApplication {
   static String QUERY_XML_FILE_PATH = "config/formdesign/safFormslist.xml";
   private String pagePath = "/customform/";
   @Autowired
   private SafFormslistRepository safFormslistRepository;
   @Autowired
   private SysFunctionRepository sysFunctionRepository;
   @Autowired
   private FormTablesRepository formTablesRepository;
   @Autowired
   private FormButtonsRepository formButtonsRepository;
   @Autowired
   private FormAttributeRepository formAttributeRepository;
   @Autowired
   private MetaDataRepository metaDataRepository;
   @Autowired
   private FormSearchSqlRepository formSearchSqlRepository;
   @Autowired
   private SysFunctionApplicationProxy sysFunctionApplication;
   @Autowired
   private CommonUtilApplication commonUtilApplication;
   @Autowired
   private BuildTypeClass buildTypeClass;

   public Map<String, Object> querySyfForms(SafFormsQueryRequest queryRequest) {
      return this.sqlExecutorDao.executeSlicedQuery(this.getQueryDescriptor(), queryRequest);
   }

   private QueryDescriptor getQueryDescriptor() {
      return this.sqlExecutorDao.getQuery(QUERY_XML_FILE_PATH, "querySafFormList");
   }

   private QueryDescriptor getQueryDescriptor(String entityName) {
      return this.sqlExecutorDao.getQuery(QUERY_XML_FILE_PATH, entityName);
   }

   private QueryDescriptor getQueryDescriptor(String filePath, String entityName) {
      return this.sqlExecutorDao.getQuery(QUERY_XML_FILE_PATH, entityName);
   }

   public List<Map<String, Object>> queryformButtonList(SafFormsQueryRequest queryRequest) {
      String sql = this.getQueryDescriptor(queryRequest.getTableName(), "formButtonList").getSql();
      return this.sqlExecutorDao.queryToListMap(sql, new Object[]{queryRequest.getId()});
   }

   public List<Map<String, Object>> queryDisplayListFields(SafFormsQueryRequest queryRequest) {
      String sql = this.getQueryDescriptor("gridListFields").getSql();
      return this.sqlExecutorDao.queryToListMap(sql, new Object[]{queryRequest.getId()});
   }

   public List<Map<String, Object>> queryDisplaySearchFields(SafFormsQueryRequest queryRequest) {
      String sql = this.getQueryDescriptor("gridSearchFields").getSql();
      return this.sqlExecutorDao.queryToListMap(sql, new Object[]{queryRequest.getId()});
   }

   public List<Map<String, Object>> queryFormParameter(FormParameterQueryRequest queryRequest) {
      String sql = "";
      if (queryRequest.getParmType() == 1) {
         sql = this.getQueryDescriptor("queryFormParameterPrompt").getSql();
      } else {
         if (queryRequest.getParmType() == 2) {
            sql = this.getQueryDescriptor("queryFormParameterSearchSQL").getSql();
            return this.sqlExecutorDao.queryToListMap(sql, new Object[]{queryRequest.getFormNo()});
         }

         if (queryRequest.getParmType() == 3) {
            sql = this.getQueryDescriptor("queryFormFunctionOrProcduce").getSql();
            return this.sqlExecutorDao.queryToListMap(sql, new Object[]{"FUNCTION"});
         }

         if (queryRequest.getParmType() == 4) {
            sql = this.getQueryDescriptor("queryFormFunctionOrProcduce").getSql();
            return this.sqlExecutorDao.queryToListMap(sql, new Object[]{"PROCEDURE"});
         }
      }

      return this.sqlExecutorDao.queryToListMap(sql, new Object[]{queryRequest.getFormNo(), queryRequest.getParmType()});
   }

   public Map<String, Object> queryFormFunctionOrProcduceContent(FormParameterQueryRequest queryRequest) {
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptor("queryFormFunctionOrProcduceContent"), queryRequest);
      String sql = queryModel.getSql();
      sql = sql + " and name='" + queryRequest.getName() + "'";
      if (queryRequest.getParmType() == 3) {
         sql = sql + " and  TYPE='FUNCTION' ";
      } else if (queryRequest.getParmType() == 4) {
         sql = sql + " and  TYPE='PROCEDURE' ";
      }

      queryModel.setSql(sql);
      Map<String, Object> mapData = this.sqlExecutorDao.executeSlicedQuery(queryModel);
      return mapData;
   }

   public SafFormslist loadSyfForms(String id) {
      Assert.hasText(id, "ID不能为空。");
      return (SafFormslist)this.safFormslistRepository.findOne(id);
   }

   @Transactional
   public void deleteSyfFormsByIds(List<String> ids) {
      List<SafFormslist> list = this.safFormslistRepository.findAll(ids);
      Iterator var4 = ids.iterator();

      while(var4.hasNext()) {
         String formId = (String)var4.next();
         this.formAttributeRepository.deleteFormAttribute(formId);
         this.formTablesRepository.deleteFormTables(formId);
         this.formButtonsRepository.deleteFormButtons(formId);
      }

      this.safFormslistRepository.delete(list);
   }

   public List<Map<String, Object>> queryTableProperty(SafFormsQueryRequest queryRequest) {
      String sql = null;
      sql = this.getQueryDescriptor(queryRequest.getTableName(), "tableProperty").getSql();
      return this.sqlExecutorDao.queryToListMap(sql, new Object[]{queryRequest.getTableName(), queryRequest.getTableName(), queryRequest.getId()});
   }

   @Transactional
   public String saveOrUpdateForm(SafFormslist form) {
      String backStr = "";
      String formId = form.getId();
      this.safFormslistRepository.saveAndFlush(form);
      this.formAttributeRepository.deleteFormAttribute(formId);
      List<FormAttribute> faList = form.getFormAttributeList();
      MetaData metaData = null;
      int u = 0;

      Iterator newFormSearchSql;
      for(newFormSearchSql = faList.iterator(); newFormSearchSql.hasNext(); ++u) {
         FormAttribute formAttr = (FormAttribute)newFormSearchSql.next();
         formAttr.setId(Utils.createUuid());
         formAttr.setFormId(formId);
         formAttr.setStatus(1);
         formAttr.setSequence(u);
         metaData = this.metaDataRepository.findByFieldCode(formAttr.getAttrCode());
         formAttr.setMetaId(metaData.getId());
         this.formAttributeRepository.save(formAttr);
      }

      List<FormSearchSql> searchSqlList = form.getFormSearchSqlList();
      newFormSearchSql = null;
      Iterator var10 = searchSqlList.iterator();

      while(var10.hasNext()) {
         FormSearchSql frmSearchSql = (FormSearchSql)var10.next();
         List<FormSearchSql> list = this.formSearchSqlRepository.searchSqlByFormNoAndSearchName(frmSearchSql.getFormNo(), frmSearchSql.getSearchName());
         if (list != null && list.size() > 0) {
            FormSearchSql formSearchSql = (FormSearchSql)list.get(0);
            formSearchSql.setTargetField(frmSearchSql.getTargetField());
            this.formSearchSqlRepository.save(formSearchSql);
         }
      }

      return backStr;
   }

   @Transactional
   public synchronized String saveTableFieldAttributeList_old(String id, String tableName, List<PropertyDefines> plist) {
      if (plist != null && plist.size() > 0) {
         SafFormslist syfForms = (SafFormslist)this.safFormslistRepository.findOne(id);
         this.assembleData(plist, syfForms);
         String[] sourceTypes = null;
         String[] fieldEns = null;
         List<FormSearchSql> list = this.formSearchSqlRepository.searchSqlByFormNo(tableName);
         if (list != null && list.size() > 0) {
            FormSearchSql syfSelectCustom = null;

            for(int i = 0; i < list.size(); ++i) {
               syfSelectCustom = (FormSearchSql)list.get(i);

               for(int j = 0; j < ((Object[])fieldEns).length; ++j) {
                  if (((String)((Object[])fieldEns)[j]).equals(syfSelectCustom.getTargetField())) {
                     if (!"2".equals(((Object[])sourceTypes)[j])) {
                        this.formSearchSqlRepository.deleteSearchSqlByTableField(tableName, (String)((Object[])fieldEns)[j]);
                     }
                     break;
                  }
               }
            }
         }

         syfForms = (SafFormslist)this.safFormslistRepository.save(syfForms);
         return syfForms.getId();
      } else {
         return "";
      }
   }

   @Transactional
   public String saveFormButtonLists(String formId, String tableName, List<FormButtonVO> blist) {
      FormButtons formButtons = null;
      this.formButtonsRepository.deleteFormButtons(formId);

      for(int i = 0; i < blist.size(); ++i) {
         formButtons = new FormButtons();
         formButtons.setId(Utils.createUuid());
         formButtons.setFormId(formId);
         formButtons.setButtonKey(((FormButtonVO)blist.get(i)).getButtonValue());
         formButtons.setButtonName(((FormButtonVO)blist.get(i)).getButtonName());
         formButtons.setButtonType(1);
         formButtons.setStatus(1);
         formButtons.setSequence(i + 1);
         formButtons.setButtonMethodName(((FormButtonVO)blist.get(i)).getButtonValue());
         this.formButtonsRepository.save(formButtons);
      }

      return formId;
   }

   @Transactional
   public String saveCustomButton(String formId, String btnName, String btnValue) {
      List<FormButtons> list = this.formButtonsRepository.findByFormId(formId);
      int zs = 1;
      if (list != null && list.size() > 0) {
         zs = list.size() + 1;
      }

      FormButtons formButtons = new FormButtons();
      formButtons.setId(Utils.createUuid());
      formButtons.setFormId(formId);
      formButtons.setButtonKey(btnValue);
      formButtons.setButtonName(btnName);
      formButtons.setButtonMethodName(btnValue);
      formButtons.setButtonType(2);
      formButtons.setStatus(1);
      formButtons.setSequence(zs);
      this.formButtonsRepository.save(formButtons);
      return formId;
   }

   @Transactional
   public String deleteCustomButton(String formId, String btnName, String btnValue) {
      this.formButtonsRepository.deleteFormButtonsByKey(formId, btnValue);
      return formId;
   }

   @Transactional
   public void deleteFormSettings(String type, List<String> ids) {
      if ("easysearch".equals(type)) {
         List<FormSearchSql> list = this.formSearchSqlRepository.findAll(ids);
         this.formSearchSqlRepository.delete(list);
      }

   }

   @Transactional
   public String saveDisplayListFields(String formId, List<FormAttribute> blist) {
      this.formAttributeRepository.updateDisplayListing(0, formId);
      FormAttribute formAttribute = null;

      for(int i = 0; i < blist.size(); ++i) {
         formAttribute = (FormAttribute)blist.get(i);
         formAttribute = (FormAttribute)this.formAttributeRepository.findOne(formAttribute.getId());
         formAttribute.setDisplayListing(1);
         this.formAttributeRepository.save(formAttribute);
      }

      return formId;
   }

   @Transactional
   public String saveSearchFields(String formId, List<FormAttribute> blist) {
      this.formAttributeRepository.updateSearchField(0, formId);
      FormAttribute formAttribute = null;

      for(int i = 0; i < blist.size(); ++i) {
         formAttribute = (FormAttribute)blist.get(i);
         formAttribute = (FormAttribute)this.formAttributeRepository.findOne(formAttribute.getId());
         formAttribute.setSearchField(1);
         this.formAttributeRepository.save(formAttribute);
      }

      return formId;
   }

   public SafFormslist assembleData(List<PropertyDefines> lists, SafFormslist syfForms) {
      lists.sort(Comparator.naturalOrder());
      StringBuffer showfieldsEn = new StringBuffer();
      StringBuffer showfieldsCh = new StringBuffer();
      StringBuffer mustinputField = new StringBuffer();
      StringBuffer listdisplayField = new StringBuffer();
      StringBuffer listdisplayFieldName = new StringBuffer();
      StringBuffer fieldTag = new StringBuffer();
      StringBuffer validatorType = new StringBuffer();
      StringBuffer dataSourceType = new StringBuffer();
      StringBuffer dataSource = new StringBuffer();
      StringBuffer sequence = new StringBuffer();
      StringBuffer showfieldsType = new StringBuffer();
      StringBuffer listdisplayFieldType = new StringBuffer();
      StringBuffer showfieldsLengths = new StringBuffer();
      StringBuffer listdisplaySearchFields = new StringBuffer();
      int i = 0;
      Iterator var19 = lists.iterator();

      while(var19.hasNext()) {
         PropertyDefines list = (PropertyDefines)var19.next();
         if (StringUtil.isNotBlank(list.getColumnName())) {
            String columnName = list.getColumnName();
            showfieldsEn.append(columnName);
            showfieldsEn.append(",");
         }

         if (StringUtil.isNotBlank(list.getComments())) {
            showfieldsCh.append(list.getComments().replaceAll(",", ""));
            showfieldsCh.append(",");
         }

         if (StringUtil.isNotBlank(list.getYesorno())) {
            mustinputField.append(list.getYesorno());
         } else {
            mustinputField.append("0");
         }

         mustinputField.append(",");
         if (StringUtil.isNotBlank(list.getListdisplayField()) && "1".equals(list.getListdisplayField())) {
            listdisplayField.append(list.getColumnName());
            listdisplayField.append(",");
            listdisplayFieldName.append(list.getComments());
            listdisplayFieldName.append(",");
            listdisplayFieldType.append(list.getDataType());
            listdisplayFieldType.append(",");
         }

         if (StringUtil.isNotBlank(list.getListdisplaySearchField())) {
            listdisplaySearchFields.append(list.getListdisplaySearchField());
         } else {
            listdisplaySearchFields.append("0");
         }

         listdisplaySearchFields.append(",");
         if (StringUtil.isNotBlank(list.getXmControlType())) {
            fieldTag.append(list.getXmControlType());
         } else {
            fieldTag.append("input");
         }

         fieldTag.append(",");
         if (StringUtil.isNotBlank(list.getValidatorType())) {
            validatorType.append(list.getValidatorType());
         }

         validatorType.append(",");
         if (StringUtil.isNotBlank(list.getDataSourceType())) {
            dataSourceType.append(list.getDataSourceType());
         }

         dataSourceType.append(",");
         if (StringUtil.isNotBlank(list.getDataSource())) {
            dataSource.append(list.getDataSource().replaceAll(",", ""));
         }

         dataSource.append(",");
         ++i;
         if (StringUtil.isNotBlank(list.getSequence())) {
            sequence.append(list.getSequence());
         } else {
            sequence.append(i);
         }

         sequence.append(",");
         if (StringUtil.isNotBlank(list.getDataType())) {
            showfieldsType.append(list.getDataType());
            showfieldsType.append(",");
         }

         if (StringUtil.isNotBlank(list.getDataLength())) {
            showfieldsLengths.append(list.getDataLength());
            showfieldsLengths.append(",");
         }
      }

      return syfForms;
   }

   public Map<String, Object> queryAlternativeTableLists(SafFormsQueryRequest queryRequest) {
      QueryDescriptor queryDescriptor = this.getQueryDescriptor("alternativeTableData");
      Map<String, Object> map = this.sqlExecutorDao.executeSlicedQuery(queryDescriptor, queryRequest);
      return map;
   }

   public List<Map<String, Object>> querySelectedTableLists(SafFormsQueryRequest queryRequest) {
      String sql = this.getQueryDescriptor("selectedTableData").getSql();
      List<Map<String, Object>> data = this.sqlExecutorDao.queryToListMap(sql, new Object[]{queryRequest.getId()});
      return data;
   }

   public String saveSafForms(SafFormslist safFormslist, List<Object> plist) {
      Map<String, Object> map = null;
      SafFormslist safForms = null;
      String backStr = "";
      boolean existMainTable = false;

      for(int i = 0; i < plist.size(); ++i) {
         map = (Map)plist.get(i);
         if ("1".equals(map.get("tableType").toString())) {
            existMainTable = true;
            break;
         }
      }

      if (!existMainTable) {
         throw new IllegalArgumentException("表单编号" + safFormslist.getFormNo() + "：没有设置主表！");
      } else {
         List formTables;
         if (safFormslist.getId() != null && !"".equals(safFormslist.getId())) {
            safForms = (SafFormslist)this.safFormslistRepository.findOne(safFormslist.getId());
            safForms.setFormNo(safFormslist.getFormNo());
            safForms.setFormName(safFormslist.getFormName());
            safForms.setSaveMode(safFormslist.getSaveMode());
            formTables = this.formTablesRepository.findByFormId(safFormslist.getId());
            Iterator var9 = formTables.iterator();

            while(var9.hasNext()) {
               FormTables table = (FormTables)var9.next();
               this.formTablesRepository.delete(table);
            }
         } else {
            safForms = new SafFormslist();
            formTables = this.safFormslistRepository.findByFormNo(safFormslist.getFormNo());
            if (formTables != null && formTables.size() > 0) {
               backStr = "表单编号已经存在！";
               throw new IllegalArgumentException("表单编号" + safFormslist.getFormNo() + "已经存在！");
            }

            safForms.setFormNo(safFormslist.getFormNo());
            safForms.setFormName(safFormslist.getFormName());
            safForms.setPackageName(safFormslist.getFormNo());
            safForms.setFormPath(safFormslist.getFormNo());
            safForms.setSaveMode(safFormslist.getSaveMode());
            if (safFormslist.getPagedatailCols() != null) {
               safForms.setPagedatailCols(safFormslist.getLabelCols());
            } else {
               safForms.setPagedatailCols(Integer.parseInt("3"));
            }

            if (safFormslist.getLabelCols() != null) {
               safForms.setLabelCols(safFormslist.getLabelCols());
            } else {
               safForms.setLabelCols(Integer.parseInt("2"));
            }

            if (safFormslist.getFieldCols() != null) {
               safForms.setFieldCols(safFormslist.getFieldCols());
            } else {
               safForms.setFieldCols(Integer.parseInt("3"));
            }

            if (safFormslist.getTextareaRows() != null) {
               safForms.setTextareaRows(safFormslist.getTextareaRows());
            } else {
               safForms.setTextareaRows(Integer.parseInt("3"));
            }

            if (safFormslist.getExistAttachment() != null) {
               safForms.setExistAttachment(safFormslist.getExistAttachment());
            } else {
               safForms.setExistAttachment(0);
            }
         }

         safForms = (SafFormslist)this.safFormslistRepository.saveAndFlush(safForms);
         formTables = null;

         for(int i = 0; i < plist.size(); ++i) {
            map = (Map)plist.get(i);
            String tableId = map.get("id").toString();
            String tableName = map.get("tableName").toString();
            String tableType = map.get("tableType").toString();
            FormTables formTable = new FormTables();
            formTable.setId(Utils.createUuid());
            formTable.setTableId(tableId);
            formTable.setFormId(safForms.getId());
            formTable.setTableName(tableName);
            formTable.setTableType(Integer.parseInt(tableType));
            formTable.setStatus(1);
            this.formTablesRepository.save(formTable);
         }

         return backStr;
      }
   }

   public Map<String, Object> produceMenuList(SafFormsQueryRequest queryRequest) {
      Map<String, Object> map = new HashMap();
      SafFormslist formList = (SafFormslist)this.safFormslistRepository.findOne(queryRequest.getId());
      String url = "/menuManage/forwardPageList.do?formNo=" + formList.getFormNo();
      SysFunction parentSysFunction = this.sysFunctionRepository.findByCode("customMenu");
      SysFunction function = this.sysFunctionRepository.findByCode(formList.getFormNo());
      if (function == null) {
         map.put("backStr", "");
         SysFunction sysFunction = new SysFunction();
         String id = Utils.createUuid();
         sysFunction.setId(id);
         sysFunction.setCode(formList.getFormNo());
         sysFunction.setName(formList.getFormName());
         sysFunction.setUrl(url);
         sysFunction.setParentId(parentSysFunction.getId());
         sysFunction.setNodeKindId("fun");
         sysFunction.setIcon("fa-file");
         sysFunction.setFullId(parentSysFunction.getFullId() + "/" + id);
         sysFunction.setFullName(parentSysFunction.getFullName() + "/" + formList.getFormName());
         sysFunction.setStatus(1);
         sysFunction = (SysFunction)this.sysFunctionRepository.saveAndFlush(sysFunction);
         this.sysFunctionApplication.buildPermission(sysFunction.getFullId());
      } else {
         map.put("backStr", "当前功能菜单编码已经存在！");
      }

      return map;
   }

   public void needGenerateFile(SafFormsQueryRequest queryRequest) {
      String webPath = this.getClass().getClassLoader().getResource("/").getPath();
      webPath = webPath.substring(1, webPath.length() - 16);
      webPath = webPath + this.pagePath;
      File file = new File(webPath);
      if (!file.exists()) {
         file.mkdir();
      }

      SafFormslist safFormslist = (SafFormslist)this.safFormslistRepository.findOne(queryRequest.getId());
      webPath = webPath + safFormslist.getFormNo();
      file = new File(webPath);
      if (!file.exists()) {
         file.mkdir();
      }

      String tableName = this.commonUtilApplication.getTablesByFormId(safFormslist.getId(), 1);
      tableName = tableName.split(",")[0];
      queryRequest.setTableName(tableName.toUpperCase());
      String pageName = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, queryRequest.getTableName());
      String filePathName = webPath + "/" + pageName + ".jsp";
      file = new File(filePathName);
      if (file.exists()) {
         file.delete();
      }

      if (!file.exists()) {
         new StringBuffer("");
         new ArrayList();
         ParamFormVO paraForm = this.getFieldAttributes(queryRequest);
         DbTablesQueryRequest dbqueryRequest = new DbTablesQueryRequest();
         dbqueryRequest.setTableName(tableName.toUpperCase());
         List<String> hiddenField = this.commonUtilApplication.queryTableHiddenFields(dbqueryRequest, 1);
         paraForm.setIsform(1);
         paraForm.setTableName(tableName);
         paraForm.setFormPath(webPath);
         paraForm.setUploadPath("");
         paraForm.setSrcPath(this.pagePath);
         paraForm.setHiddenFields(hiddenField);
         paraForm.setFormName(safFormslist.getFormName());
         List<FormButtons> buttonLists = this.formButtonsRepository.findByFormId(safFormslist.getId());
         if (buttonLists != null && buttonLists.size() > 0) {
            String[] btnNames = new String[buttonLists.size()];
            String[] btnMethodNames = new String[buttonLists.size()];
            FormButtons formButtons = null;

            for(int y = 0; y < buttonLists.size(); ++y) {
               formButtons = (FormButtons)buttonLists.get(y);
               btnNames[y] = formButtons.getButtonName();
               btnMethodNames[y] = formButtons.getButtonMethodName();
            }

            paraForm.setBtnNames(btnNames);
            paraForm.setBtnMethodNames(btnMethodNames);
         }

         try {
            BuildPageDetailFile buildPageDetailFile = new BuildPageDetailFile();
            StringBuffer sb = buildPageDetailFile.generateContents(paraForm, tableName);
            buildPageDetailFile.generateFile(filePathName, sb);
            Thread.sleep(1000L);
            this.buildTypeClass.getBuildClass("pageList").generateFile(paraForm, (List)null);
            Thread.sleep(1000L);
            this.buildTypeClass.getBuildClass("pageJS").generateFile(paraForm, (List)null);
            Thread.sleep(1000L);
         } catch (Exception var17) {
            var17.printStackTrace();
         }
      }

   }

   public ParamFormVO getFieldAttributes(SafFormsQueryRequest queryRequest) {
      List<Map<String, Object>> singleList = this.commonUtilApplication.queryDataRecordSingleFields(queryRequest.getId(), queryRequest.getTableName());
      ParamFormVO paraForms = Utils.composeAttributes(singleList, "", "", (List)null);
      List<FormSearchSql> customlists = this.formSearchSqlRepository.searchSqlByFormNo(queryRequest.getFormNo());
      List<SeleListCustomVO> listCustoms = new ArrayList();
      SeleListCustomVO customVO = null;
      Map<String, Object> map = null;
      String[] fieldEns = new String[singleList.size()];
      List<String> hiddenFields = new ArrayList();
      String backFields = "";
      String paramSourceFields = "";

      for(int i = 0; i < customlists.size(); ++i) {
         customVO = new SeleListCustomVO();
         Utils.CopyBean(customlists.get(i), customVO);
         singleList = this.commonUtilApplication.queryDataRecordSingleFields(queryRequest.getId(), customVO.getTableName());
         fieldEns = new String[singleList.size()];
         this.addParamFieldNum(queryRequest.getId(), customVO);
         if (customVO.getBackFields() != null) {
            backFields = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, customVO.getBackFields());
            customVO.setBackFields(backFields);
         }

         if (customVO.getParamSourceFields() != null) {
            paramSourceFields = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, customVO.getParamSourceFields());
            customVO.setParamSourceFields(paramSourceFields);
         }

         int j;
         for(j = 0; j < singleList.size(); ++j) {
            map = (Map)singleList.get(j);
            fieldEns[j] = map.get("fieldCode").toString();
         }

         for(j = 0; j < singleList.size(); ++j) {
            map = (Map)singleList.get(j);
            if (customVO.getTargetField() != null && customVO.getTargetField().equals(map.get("fieldCode").toString())) {
               customVO.setTargetNum(j);
               break;
            }
         }

         customVO.setFieldEns(fieldEns);
         hiddenFields.addAll(Utils.getHiddenFields(customVO));
         listCustoms.add(customVO);
      }

      paraForms.setSelectCustoms(listCustoms);
      paraForms.setHiddenFields(hiddenFields);
      new ArrayList();
      String mainTableName = queryRequest.getTableName().toLowerCase();
      queryRequest.setTableType(2);
      List<Map<String, Object>> multsList = this.queryExistTables(queryRequest);
      if (multsList != null && multsList.size() > 0) {
         new ParamFormVO();
         List<String> hiddenField = new ArrayList();
         hiddenField.add("id");
         hiddenField.add("parentId");
         List<ParamFormVO> details = new ArrayList();
         List<Map<String, Object>> list = null;

         for(int i = 0; i < multsList.size(); ++i) {
            map = (Map)multsList.get(i);
            queryRequest.setTableName(map.get("tableName").toString());
            list = this.commonUtilApplication.queryDataRecordMultsFields(queryRequest.getId(), map.get("tableName").toString());
            ParamFormVO paramVO = Utils.composeAttributes(list, map.get("tableName").toString(), map.get("name").toString(), hiddenField);
            paramVO.setDisplayFieldnames(paramVO.getFieldChs());
            paramVO.setDisplayFields(paramVO.getFieldEns());
            paramVO.setDisplayFieldTypes(paramVO.getValidatorTypes());
            paramVO.setSrcPath(this.pagePath);
            paramVO.setSelectCustoms(listCustoms);
            paramVO.setIsform(1);
            paramVO.setFormPath(queryRequest.getFormNo());
            paramVO.setMainTableName(mainTableName);
            details.add(paramVO);
         }

         paraForms.setDetails(details);
      }

      return paraForms;
   }

   public SeleListCustomVO addParamFieldNum(String formId, SeleListCustomVO customVO) {
      if (customVO.getParamFields() != null && !"".equals(customVO.getParamFields())) {
         String[] tables = customVO.getParamSourceTables().split(",");
         List<Map<String, Object>> singleList = this.commonUtilApplication.queryDataRecordSingleFields(formId, customVO.getTableName());
         List<Map<String, Object>> otherList = null;
         if (tables.length > 1) {
            String otherTable = tables[0];
            if (customVO.getTableName().equals(tables[0])) {
               otherTable = tables[1];
            }

            otherList = this.commonUtilApplication.queryDataRecordSingleFields(formId, otherTable);
         }

         String[] paraSourceField = customVO.getParamSourceFields().split(",");
         Map<String, Object> map = null;
         int[] paramSourceNums = new int[paraSourceField.length];
         boolean isFound = false;

         for(int d = 0; d < paraSourceField.length; ++d) {
            int r;
            for(r = 0; r < singleList.size(); ++r) {
               map = (Map)singleList.get(r);
               if (paraSourceField[d].equals(map.get("fieldCode").toString())) {
                  paramSourceNums[d] = r;
                  isFound = true;
                  break;
               }
            }

            if (!isFound) {
               for(r = 0; r < otherList.size(); ++r) {
                  map = (Map)otherList.get(r);
                  if (paraSourceField[d].equals(map.get("fieldCode").toString())) {
                     paramSourceNums[d] = r;
                     isFound = true;
                     break;
                  }
               }
            }
         }

         customVO.setParamSourceNums(paramSourceNums);
      }

      return customVO;
   }

   public List<Map<String, Object>> queryExistTables(SafFormsQueryRequest queryRequest) {
      new HashMap();
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptor("queryFormExistTables"), queryRequest);
      queryModel.setPageSize(101);
      queryModel.setPageIndex(1);
      String sql = queryModel.getSql();
      if (queryRequest.getTableType() != 0) {
         sql = sql + " and a.table_type=" + queryRequest.getTableType();
      }

      sql = sql + " and c.form_no='" + queryRequest.getFormNo() + "'";
      queryModel.setSql(sql);
      Map<String, Object> mapData = this.sqlExecutorDao.executeSlicedQuery(queryModel);
      List<Map<String, Object>> list = (List)mapData.get("Rows");
      return list;
   }
}
