package com.huigou.uasp.form.controller;

import com.google.common.base.CaseFormat;
import com.huigou.cache.SystemCache;
import com.huigou.uasp.annotation.ControllerMapping;
import com.huigou.uasp.builder.BuildTypeClass;
import com.huigou.uasp.builder.vo.ParamFormVO;
import com.huigou.uasp.builder.vo.SeleListCustomVO;
import com.huigou.uasp.client.CommonController;
import com.huigou.uasp.form.application.CommonUtilApplication;
import com.huigou.uasp.form.application.SafFormslistApplication;
import com.huigou.uasp.form.domain.model.FormAttribute;
import com.huigou.uasp.form.domain.model.FormButtonVO;
import com.huigou.uasp.form.domain.model.FormSearchSql;
import com.huigou.uasp.form.domain.model.PropertyDefines;
import com.huigou.uasp.form.domain.model.SafFormslist;
import com.huigou.uasp.form.domain.query.FormParameterQueryRequest;
import com.huigou.uasp.form.domain.query.SafFormsQueryRequest;
import com.huigou.uasp.form.repository.FormAttributeRepository;
import com.huigou.uasp.form.repository.FormSearchSqlRepository;
import com.huigou.uasp.form.repository.FormTablesRepository;
import com.huigou.uasp.form.repository.SafFormslistRepository;
import com.huigou.uasp.model.application.DbTablesApplication;
import com.huigou.uasp.model.domain.query.DbTablesQueryRequest;
import com.huigou.uasp.util.Utils;
import com.huigou.util.SDO;
import com.huigou.util.StringUtil;
import java.io.File;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.util.StringUtils;

@Controller
@ControllerMapping({"safFormslist"})
public class SafFormslistController extends CommonController {
   @Autowired
   private SafFormslistRepository safFormslistRepository;
   @Autowired
   private FormTablesRepository formTablesRepository;
   @Autowired
   private FormAttributeRepository formAttributeRepository;
   @Autowired
   private FormSearchSqlRepository formSearchSqlRepository;
   @Autowired
   private CommonUtilApplication commonUtilApplication;
   @Autowired
   private SafFormslistApplication safFormsApplication;
   @Autowired
   private DbTablesApplication dbTablesApplication;
   @Autowired
   private BuildTypeClass buildTypeClass;

   protected String getPagePath() {
      return "/formdesign/forms/";
   }

   public String forwardSyfFormsList() {
      this.putAttribute("uploadPath", (String)SystemCache.getParameter("uploadPath", String.class) + "/source");
      return this.forward("syfFormsList");
   }

   public String slicedQuerySyfForms() {
      SDO sdo = this.getSDO();
      SafFormsQueryRequest queryRequest = (SafFormsQueryRequest)sdo.toQueryRequest(SafFormsQueryRequest.class);
      Map<String, Object> data = this.safFormsApplication.querySyfForms(queryRequest);
      return this.toResult(data);
   }

   public String loadSyfFormsDetail() {
      String id = this.getSDO().getString("id");
      if (StringUtils.isEmpty(id)) {
         return this.forward("syfFormsDetail");
      } else {
         SafFormslist entity = this.safFormsApplication.loadSyfForms(id);
         return this.forward("syfFormsDetail", entity);
      }
   }

   public String loadSyfFormsFunction() {
      String formId = this.getSDO().getString("id");
      if (StringUtils.isEmpty(formId)) {
         return this.forward("syfFormsFunction");
      } else {
         SafFormslist entity = this.safFormsApplication.loadSyfForms(formId);
         this.putAttribute("formId", entity.getId());
         return this.forward("syfFormsFunction", entity);
      }
   }

   public String loadSyfFormsSetting() {
      String formId = this.getSDO().getString("id");
      if (StringUtils.isEmpty(formId)) {
         return this.forward("syfFormsSetting");
      } else {
         SafFormslist entity = this.safFormsApplication.loadSyfForms(formId);
         this.putAttribute("formId", entity.getId());
         return this.forward("syfFormsSetting", entity);
      }
   }

   public String loadDataSourceDetail() {
      SDO sdo = this.getSDO();
      String id = sdo.getString("id");
      String formNo = sdo.getString("formNo");
      List<SafFormslist> formList = this.safFormslistRepository.findByFormNo(formNo);
      SafFormslist form = (SafFormslist)formList.get(0);
      this.putAttribute("formNo", formNo);
      if (id != null && !"".equals(id)) {
         List<FormSearchSql> list = this.formSearchSqlRepository.findById(id);
         FormSearchSql entity = (FormSearchSql)list.get(0);
         this.putAttribute("oldSearchSql", entity.getSearchSql());
         return this.forward("dataSourceDetail", entity);
      } else {
         FormSearchSql entity = new FormSearchSql();
         entity.setFormNo(formNo);
         this.putAttribute("oldSearchSql", "");
         return this.forward("dataSourceDetail", entity);
      }
   }

   public String loadDataSourceDetailNext() {
      SDO sdo = this.getSDO();
      String id = sdo.getString("id");
      String formNo = sdo.getString("formNo");
      List<SafFormslist> formList = this.safFormslistRepository.findByFormNo(formNo);
      SafFormslist form = (SafFormslist)formList.get(0);
      String tableName = this.commonUtilApplication.getTablesByFormId(form.getId(), 1);
      tableName = tableName.split(",")[0];
      List<FormSearchSql> list = this.formSearchSqlRepository.findById(id);
      FormSearchSql entity = null;
      if (list != null && list.size() > 0) {
         entity = (FormSearchSql)list.get(0);
      }

      return this.forward("dataSourceDetailNext", entity);
   }

   private Map<String, Object> getTableAllFields_(SafFormslist form) {
      String tableName = this.commonUtilApplication.getTablesByFormId(form.getId(), 1);
      tableName = tableName.split(",")[0];
      DbTablesQueryRequest queryRequest = new DbTablesQueryRequest();
      queryRequest.setTableName(tableName.toUpperCase());
      queryRequest.setIsHidden(0);
      Map<String, Object> mapData = this.dbTablesApplication.querySubDbTableFields(queryRequest);
      List<Map<String, Object>> fieldList = (List)mapData.get("Rows");
      Map<String, Object> fieldMap = new HashMap();
      Iterator var8 = fieldList.iterator();

      while(var8.hasNext()) {
         Map<String, Object> map = (Map)var8.next();
         String fieldCode = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, map.get("fieldCode").toString());
         fieldMap.put(fieldCode, map.get("fieldName").toString());
      }

      return fieldMap;
   }

   public String saveSelectCustom() {
      SDO sdo = this.getSDO();
      String type = sdo.getString("type");
      FormSearchSql entity = (FormSearchSql)sdo.toObject(FormSearchSql.class);
      if (!"".equals(sdo.getString("paramSourceTables_text")) && !sdo.getString("paramSourceTables_text").equals(sdo.getString("paramSourceTables"))) {
         entity.setParamSourceTables(sdo.getString("paramSourceTables_text"));
      }

      String sql = entity.getSearchSql().toLowerCase().trim();
      HashMap data = new HashMap();

      try {
         String realField;
         if ("1".equals(type) && "1".equals(sdo.getString("changed"))) {
            String fields = sql.split("from")[0];
            fields = fields.substring(6, fields.length());
            realField = "";
            String fieldWidths = "";
            String fieldTypes = "";
            String paramFields = "";
            String[] field = null;
            String fieldCodes = "";
            field = fields.split(",");
            int i;
            if (fields.indexOf(".") > 0) {
               for(i = 0; i < field.length; ++i) {
                  realField = field[i].split("\\.")[1];
                  field[i] = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, realField);
               }
            }

            i = 0;

            while(true) {
               if (i >= field.length) {
                  String[] condiColumns;
                  if (sql.indexOf(":") > 0) {
                     condiColumns = sql.split(":");

                     for(int k = 1; k < condiColumns.length; ++k) {
                        if (condiColumns[k].indexOf(")") > 0) {
                           paramFields = paramFields + condiColumns[k].split(")")[0];
                        } else {
                           paramFields = paramFields + condiColumns[k].split(" ")[0];
                        }

                        if (k < condiColumns.length - 1) {
                           paramFields = paramFields + ",";
                        }
                     }
                  }

                  entity.setFieldNames(fieldCodes);
                  entity.setFieldCodes(fieldCodes);
                  entity.setFieldTypes(fieldTypes);
                  entity.setCreatedDate(new Date());
                  if (entity.getFieldWidths() == null) {
                     entity.setFieldWidths(fieldWidths);
                  }

                  entity.setParamFields(paramFields);
                  String condiTypes;
                  if (entity.getCondiColumns() != null && !"".equals(entity.getCondiColumns())) {
                     condiColumns = entity.getCondiColumns().split(",");
                     condiTypes = "";
                     int w = 0;

                     while(true) {
                        if (w >= condiColumns.length) {
                           String condiNames = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, entity.getCondiColumns());
                           entity.setCondiNames(condiNames);
                           entity.setCondiTypes(condiTypes);
                           break;
                        }

                        condiTypes = condiTypes + "java.lang.String";
                        if (w < condiColumns.length - 1) {
                           condiTypes = condiTypes + ",";
                        }

                        ++w;
                     }
                  }

                  List<SafFormslist> formList = this.safFormslistRepository.findByFormNo(entity.getFormNo());
                  condiTypes = null;
                  if (formList != null && formList.size() > 0) {
                     SafFormslist var22 = (SafFormslist)formList.get(0);
                     break;
                  }

                  throw new RuntimeException(String.format("表单编号“%s”不存在！", entity.getFormNo()));
               }

               fieldCodes = fieldCodes + field[i].trim();
               fieldWidths = fieldWidths + "100";
               if (!"id".equals(fieldCodes) && !fieldCodes.endsWith("id")) {
                  fieldTypes = fieldTypes + "0";
               } else {
                  fieldTypes = fieldTypes + "1";
               }

               if (i < field.length - 1) {
                  fieldCodes = fieldCodes + ",";
                  fieldWidths = fieldWidths + ",";
                  fieldTypes = fieldTypes + ",";
               }

               ++i;
            }
         }

         if (!"".equals(sdo.getString("id"))) {
            StringBuffer sb = this.getXml(entity);
            entity.setContent(sb.toString());
            realField = entity.getFormNo() + ".searchbox." + entity.getSearchName();
            SystemCache.removeOther(realField);
            SystemCache.putOther(realField, sb.toString());
         }

         this.formSearchSqlRepository.save(entity);
         data.put("id", entity.getId());
      } catch (Exception var16) {
         var16.printStackTrace();
      }

      return this.toResult(data);
   }

   private StringBuffer getXml(FormSearchSql entity) {
      StringBuffer sb = new StringBuffer("");
      sb.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>").append("<easy-search-mappings>").append("<easy-search name=\"").append(entity.getSearchName()).append("\" desc=\"").append(entity.getSearchDesc()).append("\">").append("<sql>").append(entity.getSearchSql()).append("</sql>");
      String[] fieldCode = entity.getFieldCodes().split(",");
      String[] fieldType = entity.getFieldTypes().split(",");
      String[] fieldName = entity.getFieldNames().split(",");
      String[] fieldWidth = entity.getFieldWidths().split(",");

      for(int u = 0; u < fieldCode.length; ++u) {
         if ("1".equals(fieldType[u])) {
            sb.append("<field name=\"").append(fieldCode[u]).append("\" code=\"").append(fieldCode[u]).append("\" type=\"hidden\" />");
         } else {
            sb.append("<field name=\"").append(fieldName[u]).append("\" code=\"").append(fieldCode[u]).append("\" width=\"").append(fieldWidth[u]).append("\" />");
         }
      }

      if (entity.getCondiColumns() != null && !"".equals(entity.getCondiColumns())) {
         String[] condiCol = entity.getCondiColumns().split(",");
         String[] condiType = entity.getCondiTypes().split(",");
         String[] condiSymb = entity.getCondiSymbols().split(",");
         String[] condiAlias = entity.getCondiAlias().split(",");

         for(int u = 0; u < condiCol.length; ++u) {
            sb.append("<condition column=\"").append(condiCol[u]).append("\" name=\"").append(CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, condiCol[u])).append("\" type=\"").append(condiType[u]).append("\" symbol=\"").append(condiSymb[u]).append("\" alias=\"").append(condiAlias[u]).append("\"/>");
         }
      }

      sb.append("<orderby>").append(entity.getOrderby()).append("</orderby>");
      sb.append("</easy-search>").append(" </easy-search-mappings>");
      return sb;
   }

   public String deleteFormSettings() {
      SDO sdo = this.getSDO();
      String type = sdo.getString("type");
      List<String> list = this.getSDO().getIds();
      this.safFormsApplication.deleteFormSettings(type, list);
      return this.success(sdo.getString("id"));
   }

   public String forwardTableProperty() {
      SDO sdo = this.getSDO();
      return this.forward("tableProperty", sdo);
   }

   public String slicedQueryFormButton() {
      SDO sdo = this.getSDO();
      SafFormsQueryRequest queryRequest = (SafFormsQueryRequest)sdo.toQueryRequest(SafFormsQueryRequest.class);
      List<Map<String, Object>> data = this.safFormsApplication.queryformButtonList(queryRequest);
      return this.packGridDataAndResult(data);
   }

   public String slicedQueryGridFields() {
      SDO sdo = this.getSDO();
      SafFormsQueryRequest queryRequest = (SafFormsQueryRequest)sdo.toQueryRequest(SafFormsQueryRequest.class);
      List<Map<String, Object>> data = null;
      if ("list".equals(sdo.getString("type"))) {
         data = this.safFormsApplication.queryDisplayListFields(queryRequest);
      } else {
         data = this.safFormsApplication.queryDisplaySearchFields(queryRequest);
      }

      return this.packGridDataAndResult(data);
   }

   public String slicedQueryFormParameter() {
      SDO sdo = this.getSDO();
      FormParameterQueryRequest queryRequest = (FormParameterQueryRequest)sdo.toQueryRequest(FormParameterQueryRequest.class);
      List<Map<String, Object>> data = null;
      data = this.safFormsApplication.queryFormParameter(queryRequest);
      return this.packGridDataAndResult(data);
   }

   public String loadFunctionOrProcduceContent() {
      String id = this.getSDO().getString("id");
      String name = this.getSDO().getString("name");
      this.putAttribute("name", name);
      return this.forward("viewProcduceContent");
   }

   public String slicedQueryFormFunctionOrProcduceContent() {
      SDO sdo = this.getSDO();
      FormParameterQueryRequest queryRequest = (FormParameterQueryRequest)sdo.toQueryRequest(FormParameterQueryRequest.class);
      Map<String, Object> data = this.safFormsApplication.queryFormFunctionOrProcduceContent(queryRequest);
      return this.toResult(data);
   }

   public String queryTableProperty() {
      SDO sdo = this.getSDO();

      try {
         SafFormsQueryRequest queryRequest = (SafFormsQueryRequest)sdo.toQueryRequest(SafFormsQueryRequest.class);
         List<Map<String, Object>> data = this.safFormsApplication.queryTableProperty(queryRequest);
         return this.packGridDataAndResult(data);
      } catch (Exception var4) {
         return this.error(var4);
      }
   }

   public String saveSafForms() {
      SDO sdo = this.getSDO();
      SafFormslist entity = (SafFormslist)sdo.toObject(SafFormslist.class);
      List<Object> plist = sdo.getList("detailData1");
      this.safFormsApplication.saveSafForms(entity, plist);
      return this.success();
   }

   public String saveTableFieldAttributeList_old() {
      SDO sdo = this.getSDO();
      String tableName = sdo.getString("tableName");
      String id = sdo.getString("id");
      List<PropertyDefines> plist = sdo.getList("detailData1", PropertyDefines.class);
      if (plist != null && plist.size() > 0) {
         id = this.safFormsApplication.saveTableFieldAttributeList_old(id, tableName, plist);
      }

      return this.success(id);
   }

   public String saveFormButtonLists() {
      SDO sdo = this.getSDO();
      String tableName = sdo.getString("tableName");
      String formId = sdo.getString("formId");
      List<FormButtonVO> plist = sdo.getList("detailData1", FormButtonVO.class);
      String id = "";
      if (plist != null && plist.size() > 0) {
         id = this.safFormsApplication.saveFormButtonLists(formId, tableName, plist);
      }

      return this.success(id);
   }

   public String saveDisplayFields() {
      SDO sdo = this.getSDO();
      String formId = sdo.getString("formId");
      List<FormAttribute> plist = sdo.getList("detailData1", FormAttribute.class);
      String id = "";
      if (plist != null && plist.size() > 0) {
         id = this.safFormsApplication.saveDisplayListFields(formId, plist);
      }

      return this.success(id);
   }

   public String saveSearchFields() {
      SDO sdo = this.getSDO();
      String tableName = sdo.getString("tableName");
      String formId = sdo.getString("formId");
      List<FormAttribute> plist = sdo.getList("detailData1", FormAttribute.class);
      String id = "";
      if (plist != null && plist.size() > 0) {
         id = this.safFormsApplication.saveSearchFields(formId, plist);
      }

      return this.success(id);
   }

   public String saveCustomButton() {
      SDO sdo = this.getSDO();
      String btnName = sdo.getString("buttonName");
      String btnValue = sdo.getString("buttonValue");
      this.safFormsApplication.saveCustomButton(sdo.getString("id"), btnName, btnValue);
      return this.success(sdo.getString("id"));
   }

   public String deleteCustomButton() {
      SDO sdo = this.getSDO();
      String btnName = sdo.getString("buttonName");
      String btnValue = sdo.getString("buttonValue");
      this.safFormsApplication.deleteCustomButton(sdo.getString("id"), btnName, btnValue);
      return this.success(sdo.getString("id"));
   }

   public String loadCustomButtonDetail() {
      return this.forward("customButtonDetail");
   }

   public String deleteSyfForms() {
      this.safFormsApplication.deleteSyfFormsByIds(this.getSDO().getIds());
      return this.success();
   }

   public String produceSourceCode() {
      SDO sdo = this.getSDO();
      String id = sdo.getString("id");
      String tableName = sdo.getString("tableName");
      tableName = tableName.split(",")[0];
      DbTablesQueryRequest queryRequest = (DbTablesQueryRequest)sdo.toQueryRequest(DbTablesQueryRequest.class);
      SafFormslist form = (SafFormslist)this.safFormslistRepository.findOne(id);
      List<Map<String, Object>> fieldList = this.dbTablesApplication.queryDbTableColumns(queryRequest);
      String backStr = "1";
      SafFormsQueryRequest formQueryRequest = (SafFormsQueryRequest)sdo.toQueryRequest(SafFormsQueryRequest.class);
      formQueryRequest.setTableName(tableName);
      Map<String, Object> map = this.safFormsApplication.querySyfForms(formQueryRequest);
      Map<String, Object> pageMap = (Map)((List)map.get("Rows")).get(0);
      String packageName = pageMap.get("packageName").toString();
      String formPath = pageMap.get("formPath").toString();
      tableName = tableName.toLowerCase();
      pageMap.put("tableName", tableName);
      ParamFormVO paraForm = null;

      try {
         List<FormSearchSql> customlists = this.formSearchSqlRepository.searchSqlByFormNo(form.getFormNo());
         List<SeleListCustomVO> listNew = new ArrayList();
         SeleListCustomVO customVO = null;
         String backFields = "";
         String paramSourceFields = "";

         for(int i = 0; i < customlists.size(); ++i) {
            customVO = new SeleListCustomVO();
            Utils.CopyBean(customlists.get(i), customVO);
            if (customVO.getBackFields() != null) {
               backFields = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, customVO.getBackFields());
               customVO.setBackFields(backFields);
            }

            if (customVO.getParamSourceFields() != null) {
               paramSourceFields = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, customVO.getParamSourceFields());
               customVO.setParamSourceFields(paramSourceFields);
            }

            listNew.add(customVO);
         }

         pageMap.put("selectCustcoms", listNew);
         paraForm = this.getParamFormVO(pageMap);
         File file = null;
         String[] paths = packageName.split("\\.");
         String srcPath = paraForm.getUploadPath();
         file = new File(srcPath);
         if (!file.exists()) {
            file.mkdir();
         }

         for(int i = 0; i < paths.length; ++i) {
            file = new File(srcPath + "/" + paths[i]);
            if (!file.exists()) {
               file.mkdir();
            }

            srcPath = srcPath + "/" + paths[i];
         }

         paraForm.setSrcPath(srcPath);
         if (fieldList.size() > 0) {
            this.buildTypeClass.getBuildClass("entity").generateFile(paraForm, fieldList);
            backStr = this.buildTypeClass.getBuildClass("queryRequest").generateFile(paraForm, (List)null);
         }

         backStr = this.buildTypeClass.getBuildClass("repository").generateFile(paraForm, (List)null);
         backStr = this.buildTypeClass.getBuildClass("application").generateFile(paraForm, (List)null);
         backStr = this.buildTypeClass.getBuildClass("controller").generateFile(paraForm, (List)null);
         String[] filePaths = formPath.split("/");
         srcPath = paraForm.getUploadPath();

         for(int i = 0; i < filePaths.length; ++i) {
            file = new File(srcPath + "/" + filePaths[i]);
            if (!file.exists()) {
               file.mkdir();
            }

            srcPath = srcPath + "/" + filePaths[i];
         }

         paraForm.setSrcPath(srcPath);
         backStr = this.buildTypeClass.getBuildClass("pageList").generateFile(paraForm, (List)null);
         backStr = this.buildTypeClass.getBuildClass("pageDetail").generateFile(paraForm, (List)null);
         backStr = this.buildTypeClass.getBuildClass("pageJS").generateFile(paraForm, (List)null);
         backStr = this.buildTypeClass.getBuildClass("xml").generateFile(paraForm, (List)null);
      } catch (Exception var24) {
         var24.printStackTrace();
      }

      System.out.println("===========Sucess Complete GenerateCode!!!==========");
      return this.toResult(backStr);
   }

   public String producePageFile() {
      String backStr = "";
      SDO sdo = this.getSDO();
      String tableName = sdo.getString("tableName");
      SafFormsQueryRequest formQueryRequest = (SafFormsQueryRequest)sdo.toQueryRequest(SafFormsQueryRequest.class);
      formQueryRequest.setTableName(tableName);
      this.safFormsApplication.needGenerateFile(formQueryRequest);
      return this.toResult(backStr);
   }

   public ParamFormVO getParamFormVO(Map<String, Object> pageMap) {
      ParamFormVO paraForm = new ParamFormVO();

      try {
         paraForm.setIsform(0);
         paraForm.setUploadPath((String)SystemCache.getParameter("uploadPath", String.class) + "/source");
         paraForm.setTableName(pageMap.get("tableName").toString());
         paraForm.setPackageName(pageMap.get("packageName").toString());
         paraForm.setFormPath(pageMap.get("formPath").toString());
         paraForm.setFormName(pageMap.get("formName").toString());
         paraForm.setFieldEns(pageMap.get("showfieldsEn").toString().split(","));
         paraForm.setFieldChs(pageMap.get("showfieldsCh").toString().split(","));
         paraForm.setValidatorTypes(pageMap.get("validatorType").toString().split(","));
         paraForm.setFieldTags(pageMap.get("fieldTag").toString().split(","));
         paraForm.setDataSourceTypes(pageMap.get("dataSourceType").toString().split(","));
         paraForm.setDataSources(pageMap.get("dataSource").toString().split(";"));
         paraForm.setMustinputFields(pageMap.get("mustinputField").toString().split(","));
         paraForm.setFieldsLengths(pageMap.get("showfieldsLengths").toString().split(","));
         paraForm.setBtnNames(pageMap.get("formbuttonsName").toString().split(","));
         paraForm.setBtnMethodNames(pageMap.get("formbuttonsMethodName").toString().split(","));
         paraForm.setDisplayFields(pageMap.get("listdisplayField").toString().split(","));
         paraForm.setDisplayFieldnames(pageMap.get("listdisplayFieldname").toString().split(","));
         paraForm.setDisplayFieldTypes(pageMap.get("listdisplayFieldType").toString().split(","));
         paraForm.setSearchFields(pageMap.get("listdisplaySearchField").toString().split(","));
         paraForm.setCssStyle(pageMap.get("cssStyle").toString().split(","));
         paraForm.setCheckFunction(pageMap.get("checkFunction").toString().split(","));
         paraForm.setPagedatailCols(!"".equals(pageMap.get("pagedatailCols")) ? pageMap.get("pagedatailCols").toString() : "3");
         paraForm.setLabelCols(Integer.parseInt(pageMap.get("labelCols").toString()));
         paraForm.setFieldCols(Integer.parseInt(pageMap.get("fieldCols").toString()));
         paraForm.setTextAreaRows(Integer.parseInt(pageMap.get("textareaRows").toString()));
         paraForm.setExistAttachment(Integer.parseInt(pageMap.get("existAttachment").toString()));
         if (pageMap.get("selectCustcoms") != null) {
            paraForm.setSelectCustoms((List)pageMap.get("selectCustcoms"));
         } else {
            paraForm.setSelectCustoms((List)null);
         }

         List<String> hiddenList = new ArrayList();
         hiddenList.add("id");
         paraForm.setHiddenFields(hiddenList);
         if ("1".equals(pageMap.get("existAttachment").toString())) {
            hiddenList.add("attbizid");
            paraForm.setHiddenFields(hiddenList);
         }
      } catch (Exception var4) {
         var4.printStackTrace();
      }

      return paraForm;
   }

   public String queryAlternativeTableLists() {
      SDO sdo = this.getSDO();
      SafFormsQueryRequest queryRequest = (SafFormsQueryRequest)sdo.toQueryRequest(SafFormsQueryRequest.class);
      Map<String, Object> data = this.safFormsApplication.queryAlternativeTableLists(queryRequest);
      return this.toResult(data);
   }

   public String querySelectedTableLists() {
      SDO sdo = this.getSDO();
      SafFormsQueryRequest queryRequest = (SafFormsQueryRequest)sdo.toQueryRequest(SafFormsQueryRequest.class);
      List<Map<String, Object>> data = this.safFormsApplication.querySelectedTableLists(queryRequest);
      return this.packGridDataAndResult(data);
   }

   public String produceMenuList() {
      SDO sdo = this.getSDO();
      SafFormsQueryRequest queryRequest = (SafFormsQueryRequest)sdo.toQueryRequest(SafFormsQueryRequest.class);
      Map<String, Object> data = this.safFormsApplication.produceMenuList(queryRequest);
      return this.toResult(data);
   }

   public String getExistFormNo() {
      SDO sdo = this.getSDO();
      String id = sdo.getString("id");
      Map<String, Object> map = new HashMap();
      map.put("flag", "0");
      List<SafFormslist> list = this.safFormslistRepository.findByFormNo(sdo.getString("formNo"));
      if (list != null && list.size() > 0) {
         if (StringUtil.isNotBlank(id)) {
            SafFormslist safFormslist = (SafFormslist)list.get(0);
            if (!id.equals(safFormslist.getId())) {
               map.put("flag", "1");
            }
         } else {
            map.put("flag", "1");
         }
      }

      return this.toResult(map);
   }
}
