package com.huigou.uasp.meta.application.impl;

import com.huigou.data.query.model.QueryDescriptor;
import com.huigou.uasp.bmp.common.application.BaseApplication;
import com.huigou.uasp.meta.application.MetaDataApplication;
import com.huigou.uasp.meta.domain.model.MetaData;
import com.huigou.uasp.meta.domain.model.MetaDataDICT;
import com.huigou.uasp.meta.domain.query.MetaDataQueryRequest;
import com.huigou.uasp.meta.repository.MetaDataDICTRepository;
import com.huigou.uasp.meta.repository.MetaDataRepository;
import java.util.List;
import java.util.Map;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;

@Service("metaDataApplication")
public class MetaDataApplicationImpl extends BaseApplication implements MetaDataApplication {
   static String QUERY_XML_FILE_PATH = "config/formdesign/metaData.xml";
   @Autowired
   private MetaDataRepository mdmMetaDataRepository;
   @Autowired
   private MetaDataDICTRepository mdmMetaDataDICTRepository;

   public Map<String, Object> queryMdmMetaData(MetaDataQueryRequest queryRequest) {
      return this.sqlExecutorDao.executeSlicedQuery(this.getQueryDescriptor(), queryRequest);
   }

   private QueryDescriptor getQueryDescriptor() {
      return this.sqlExecutorDao.getQuery(QUERY_XML_FILE_PATH, "mdmMetaData");
   }

   public MetaData loadMdmMetaData(String id) {
      Assert.hasText(id, "ID不能为空。");
      return (MetaData)this.mdmMetaDataRepository.findOne(id);
   }

   @Transactional
   public void deleteMdmMetaDataByIds(List<String> ids) {
      List<MetaData> list = this.mdmMetaDataRepository.findAll(ids);
      this.mdmMetaDataRepository.delete(list);
   }

   public void updateStatus(String id, Integer status) {
      MetaData one = (MetaData)this.mdmMetaDataRepository.findOne(id);
      one.setStatus(status);
      this.mdmMetaDataRepository.save(one);
   }

   public Map<String, Object> queryMdmMetaDataDICT(MetaDataQueryRequest queryRequest) {
      QueryDescriptor queryDescriptor = this.sqlExecutorDao.getQuery(QUERY_XML_FILE_PATH, "mdmMetaDataDICT");
      Map<String, Object> map = this.sqlExecutorDao.executeSlicedQuery(queryDescriptor, queryRequest);
      return map;
   }

   public void saveCopyMdmMetaData(String newBusinessDataId, List<MetaData> detailData) {
      List<MetaData> byClassifyId = this.mdmMetaDataRepository.findByClassifyId(newBusinessDataId);
      int dataSize = byClassifyId.size();
      int newDataSize = detailData.size();
      if (dataSize < newDataSize) {
         for(int i = dataSize; i < newDataSize; ++i) {
            MetaData mdmMetaData = (MetaData)detailData.get(i);
            String id = mdmMetaData.getId();
            mdmMetaData.setClassifyId(newBusinessDataId);
            mdmMetaData.setId("");
            this.mdmMetaDataRepository.save(mdmMetaData);
            MetaDataDICT mdmMetaDataDICT = this.mdmMetaDataDICTRepository.findByMetaDataId(id);
            if (mdmMetaDataDICT != null) {
               mdmMetaDataDICT.setId("");
               mdmMetaDataDICT.setClassifyId(newBusinessDataId);
               MetaData byClassifyIdAndfAndFieldName = this.mdmMetaDataRepository.findByClassifyIdAndfAndFieldName(newBusinessDataId, mdmMetaData.getFieldName());
               mdmMetaDataDICT.setMetaDataId(byClassifyIdAndfAndFieldName.getId());
               this.mdmMetaDataDICTRepository.save(mdmMetaDataDICT);
            }
         }
      } else {
         Assert.hasText("", "未选择复制的数据。");
      }

   }

   public String getMdmUserDictFolderIds(String dictName) {
      StringBuffer sb = new StringBuffer();
      sb = sb.append("select id from SA_CommonTree t start with name = '").append(dictName).append("' connect by t.parent_id= prior id");
      String sql = sb.toString();
      List<String> ids = this.sqlExecutorDao.queryToList(sql, String.class, (Object[])null);
      String resultIds = String.join(",", ids);
      return resultIds;
   }
}
