package com.huigou.uasp.model.application.impl;

import com.huigou.data.query.model.QueryDescriptor;
import com.huigou.data.query.model.QueryModel;
import com.huigou.exception.ApplicationException;
import com.huigou.uasp.bmp.common.application.BaseApplication;
import com.huigou.uasp.form.repository.SafFormslistRepository;
import com.huigou.uasp.model.application.DbTablesApplication;
import com.huigou.uasp.model.domain.model.DbTables;
import com.huigou.uasp.model.domain.model.TablesMeta;
import com.huigou.uasp.model.domain.query.DbTablesQueryRequest;
import com.huigou.uasp.model.repository.DbTablesRepository;
import com.huigou.uasp.model.repository.TablesMetaRepository;
import com.huigou.uasp.util.Utils;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service("dbTablesApplication")
public class DbTablesApplicationImpl extends BaseApplication implements DbTablesApplication {
   static String QUERY_XML_FILE_PATH = "config/formdesign/dbtables.xml";
   @Autowired
   private DbTablesRepository dbTablesRepository;
   @Autowired
   private TablesMetaRepository tablesMetaRepository;
   @Autowired
   private SafFormslistRepository syfFormsRepository;
   @Autowired
   private DbTableService dbTableService;
   private String pagePath = "/biz/mdm/model/";

   public Map<String, Object> queryDbTables(DbTablesQueryRequest queryRequest) {
      return this.sqlExecutorDao.executeSlicedQuery(this.getQueryDescriptor("dbTables"), queryRequest);
   }

   public List<Map<String, Object>> queryDbTableColumns(DbTablesQueryRequest queryRequest) {
      String sql = this.sqlExecutorDao.getQuery(QUERY_XML_FILE_PATH, "dbTables_columns").getSql();
      return this.sqlExecutorDao.queryToListMap(sql, new Object[]{queryRequest.getTableName(), queryRequest.getTableName()});
   }

   public Map<String, Object> queryUserTables(DbTablesQueryRequest queryRequest) {
      return this.sqlExecutorDao.executeSlicedQuery(this.sqlExecutorDao.getQuery(QUERY_XML_FILE_PATH, "userTables"), queryRequest);
   }

   public Map<String, Object> queryExistTableName(DbTablesQueryRequest queryRequest) {
      Map<String, Object> map = new HashMap();
      map.put("result", "");
      List<DbTables> list = this.dbTablesRepository.findByTableName(queryRequest.getTableName().toUpperCase());
      if (queryRequest.getId() != null && !"".equals(queryRequest.getId())) {
         if (list != null && list.size() > 0) {
            DbTables dbTables = (DbTables)list.get(0);
            if (!dbTables.getId().equals(queryRequest.getId())) {
               map.put("result", "表名" + queryRequest.getTableName().toUpperCase() + "已经存在！");
            }
         }
      } else if (list.size() > 0) {
         map.put("result", "表名" + queryRequest.getTableName().toUpperCase() + "已经存在！");
      }

      return map;
   }

   @Transactional
   public String saveUserTables(DbTablesQueryRequest queryRequest, List<Object> plist) {
      Map<String, Object> map = null;
      DbTables dbtable = null;
      String backStr = "";
      List dblist;
      if (queryRequest.getId() != null && !"".equals(queryRequest.getId())) {
         dbtable = (DbTables)this.dbTablesRepository.findOne(queryRequest.getId());
         dbtable.setTableName(queryRequest.getTableName().toUpperCase());
         dbtable.setName(queryRequest.getName());
         this.tablesMetaRepository.deleteTablesMetaByTableId(dbtable.getId());
      } else {
         dbtable = new DbTables();
         dblist = this.dbTablesRepository.findByTableName(queryRequest.getTableName().toUpperCase());
         if (dblist != null && dblist.size() > 0) {
            backStr = "表名已经存在！";
            throw new IllegalArgumentException("表名" + queryRequest.getTableName().toUpperCase() + "已经存在！");
         }

         dbtable.setTableName(queryRequest.getTableName().toUpperCase());
         dbtable.setParentId(queryRequest.getParentId());
         dbtable.setTableType("2");
         dbtable.setType("2");
         dbtable.setStatus(1);
         dbtable.setPublished(0);
         dbtable.setName(queryRequest.getName());
      }

      dbtable = (DbTables)this.dbTablesRepository.saveAndFlush(dbtable);
      dblist = null;

      for(int i = 0; i < plist.size(); ++i) {
         map = (Map)plist.get(i);
         String metaId = map.get("id").toString();
         String fieldCode = map.get("fieldCode").toString();
         TablesMeta tablesMeta = new TablesMeta();
         tablesMeta.setId(Utils.createUuid());
         tablesMeta.setTableId(dbtable.getId());
         tablesMeta.setMetaId(metaId);
         tablesMeta.setFieldCode(fieldCode);
         tablesMeta.setNums(Integer.parseInt(map.get("nums") != null ? map.get("nums").toString() : "0"));
         tablesMeta.setStatus(1);
         this.tablesMetaRepository.save(tablesMeta);
      }

      return backStr;
   }

   @Transactional
   public void deleteUserTables(List<String> ids) {
      List<DbTables> dblist = this.dbTablesRepository.findAll(ids);
      DbTables obj = null;

      for(int i = 0; i < dblist.size(); ++i) {
         obj = (DbTables)dblist.get(i);
         List<TablesMeta> metaLists = this.tablesMetaRepository.findByTableId(obj.getId());
         Iterator var7 = metaLists.iterator();

         while(var7.hasNext()) {
            TablesMeta meta = (TablesMeta)var7.next();
            this.tablesMetaRepository.delete(meta);
         }
      }

      this.dbTablesRepository.delete(dblist);
   }

   public void deleteModelClassData(List<String> ids) {
      List<DbTables> dblist = this.dbTablesRepository.findAll(ids);
      DbTables obj = null;
      List<?> list = null;
      boolean flag = true;

      for(int i = 0; i < dblist.size(); ++i) {
         obj = (DbTables)dblist.get(i);
         list = this.dbTablesRepository.findByParentId(obj.getId());
         if (list != null && list.size() > 0) {
            flag = false;
            throw new ApplicationException(obj.getTableName() + obj.getName() + "存在子节点，不能删除！");
         }
      }

      if (flag) {
         this.dbTablesRepository.delete(dblist);
      }

   }

   public Map<String, Object> querySubDbTables(DbTablesQueryRequest queryRequest) {
      return this.sqlExecutorDao.executeQuery(this.getQueryDescriptor("dbTables"), queryRequest);
   }

   public Map<String, Object> querySubDbTableFields(DbTablesQueryRequest queryRequest) {
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptor("dbTableFields"), queryRequest);
      Map<String, Object> map = new HashMap();
      if (queryRequest.getTableId() != null) {
         map.put("tableId", queryRequest.getTableId());
      }

      if (queryRequest.getTableName() != null) {
         map.put("tableName", queryRequest.getTableName());
      }

      if (queryRequest.getIsHidden() != null) {
         map.put("isHidden", queryRequest.getIsHidden());
      }

      queryModel.setSortFieldName("is_hidden");
      queryModel.setPageSize(100);
      queryModel.setPageIndex(1);
      queryModel.setQueryParams(map);
      return this.sqlExecutorDao.executeSlicedQuery(queryModel);
   }

   private QueryDescriptor getQueryDescriptor(String entityName) {
      return this.sqlExecutorDao.getQuery(QUERY_XML_FILE_PATH, entityName);
   }

   public Map<String, Object> queryAlternativeMetaLists(DbTablesQueryRequest queryRequest) {
      QueryDescriptor queryDescriptor = this.getQueryDescriptor("alternativeMetaData");
      Map<String, Object> map = this.sqlExecutorDao.executeSlicedQuery(queryDescriptor, queryRequest);
      return map;
   }

   public List<Map<String, Object>> querySelectedMetaLists(DbTablesQueryRequest queryRequest) {
      String sql = this.getQueryDescriptor("selectedMetaData").getSql();
      List<Map<String, Object>> data = this.sqlExecutorDao.queryToListMap(sql, new Object[]{queryRequest.getTableId()});
      return data;
   }

   @Transactional
   public Map<String, Object> publishToModelRecordTable(DbTablesQueryRequest queryRequest) {
      Map<String, Object> map = new HashMap();
      String backStr = "";
      String tableName = this.dbTableService.getTableName(queryRequest.getTableId());

      try {
         List<Map<String, Object>> fieldList = this.queryModelRecordSingleFields(queryRequest);
         if (fieldList.size() == 0) {
            map.put("result", "当前模型没有配置属性！");
            return map;
         }

         String[] fieldContent = this.dbTableService.composizeFieldContent(fieldList, "1");
         backStr = this.dbTableService.createTable(tableName, fieldContent[0], fieldContent[1]);
         if (!"".equals(backStr)) {
            map.put("result", backStr);
            return map;
         }

         map.put("result", backStr);
      } catch (Exception var7) {
         backStr = var7.getMessage();
         var7.printStackTrace();
      }

      return map;
   }

   public List<Map<String, Object>> queryModelRecordSingleFields(DbTablesQueryRequest queryRequest) {
      new HashMap();
      QueryModel queryModel = this.sqlExecutorDao.getQueryModel(this.getQueryDescriptor("dbTables"), queryRequest);
      queryModel.setPageSize(101);
      queryModel.setPageIndex(1);
      StringBuffer sb = new StringBuffer("");
      sb.append(" select  s.id,s.field_name, s.field_code, s.field_data_type, s.field_length,s.field_decimal").append(",s.code_rule_id,s.is_null,s.field_engname,s.default_value,s.is_primary_key,m.nums ").append(" from SAF_TABLES t ,SAF_TABLES_META m,SAF_META_DATA s ").append(" where m.table_id=t.id and  s.id=m.meta_id  and t.id='").append(queryRequest.getId()).append("'").append(" order by m.nums asc ");
      queryModel.setSortFieldName("nums");
      queryModel.setSql(sb.toString());
      if ("all".equals(queryModel.getExportType())) {
         queryModel.setExportType((String)null);
      }

      Map<String, Object> mapData = this.sqlExecutorDao.executeSlicedQuery(queryModel);
      List<Map<String, Object>> list = (List)mapData.get("Rows");
      return list;
   }
}
