package com.huigou.uasp.model.controller;

import com.huigou.data.repository.GeneralRepository;
import com.huigou.uasp.annotation.ControllerMapping;
import com.huigou.uasp.bmp.fn.impl.OrgFun;
import com.huigou.uasp.client.CommonController;
import com.huigou.uasp.form.application.SafFormslistApplication;
import com.huigou.uasp.model.application.DbTablesApplication;
import com.huigou.uasp.model.domain.model.DbTables;
import com.huigou.uasp.model.domain.model.TablesMeta;
import com.huigou.uasp.model.domain.query.DbTablesQueryRequest;
import com.huigou.uasp.model.repository.DbTablesRepository;
import com.huigou.uasp.model.repository.TablesMetaRepository;
import com.huigou.uasp.util.Utils;
import com.huigou.util.SDO;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;

@Controller
@ControllerMapping({"dbSettings"})
public class DataBaseSettingsController extends CommonController {
   @Autowired
   private DbTablesRepository dbTablesRepository;
   @Autowired
   private TablesMetaRepository tablesMetaRepository;
   @Autowired
   private GeneralRepository generalRepository;
   @Autowired
   private OrgFun orgFun;
   Logger logger = Logger.getLogger(this.getClass());
   @Autowired
   DbTablesApplication dbTablesApplication;
   @Autowired
   SafFormslistApplication syfFormsApplication;

   protected String getPagePath() {
      return "/formdesign/model/";
   }

   public String forwardDatabaseSettingsList() {
      return this.forward("databaseSettings");
   }

   public String queryDbTables() {
      SDO sdo = this.getSDO();

      try {
         DbTablesQueryRequest queryRequest = (DbTablesQueryRequest)sdo.toQueryRequest(DbTablesQueryRequest.class);
         Map<String, Object> data = this.dbTablesApplication.queryDbTables(queryRequest);
         return this.toResult(data);
      } catch (Exception var4) {
         return this.error(var4);
      }
   }

   public String slicedQueryDbTables() {
      SDO sdo = this.getSDO();
      DbTablesQueryRequest queryRequest = (DbTablesQueryRequest)sdo.toQueryRequest(DbTablesQueryRequest.class);
      String parentId = sdo.getString("parentId");
      Integer nodeType = sdo.getInteger("nodeType");
      Map<String, Object> data = this.dbTablesApplication.querySubDbTables(queryRequest);
      return this.toResult(data);
   }

   public String slicedQueryDbTablesFields() {
      SDO sdo = this.getSDO();
      DbTablesQueryRequest queryRequest = (DbTablesQueryRequest)sdo.toQueryRequest(DbTablesQueryRequest.class);
      String parentId = sdo.getString("parentId");
      Integer nodeType = sdo.getInteger("nodeType");
      Map<String, Object> data = this.dbTablesApplication.querySubDbTableFields(queryRequest);
      return this.toResult(data);
   }

   public String forwardUserTables() {
      SDO sdo = this.getSDO();
      String id = sdo.getString("parentId");
      if (id != null && !"".equals(id)) {
         DbTables dbTables = (DbTables)this.dbTablesRepository.findOne(id);
         if ("2".equals(dbTables.getType())) {
            this.putAttribute("parentId", dbTables.getParentId());
            return this.forward("userTablesList", dbTables);
         } else {
            this.putAttribute("parentId", sdo.getString("parentId"));
            return this.forward("userTablesList");
         }
      } else {
         this.putAttribute("parentId", sdo.getString("parentId"));
         return this.forward("userTablesList");
      }
   }

   public String queryUserTables() {
      SDO sdo = this.getSDO();

      try {
         DbTablesQueryRequest queryRequest = (DbTablesQueryRequest)sdo.toQueryRequest(DbTablesQueryRequest.class);
         Map<String, Object> data = this.dbTablesApplication.queryUserTables(queryRequest);
         return this.toResult(data);
      } catch (Exception var4) {
         return this.error(var4);
      }
   }

   public String findExistTableName() {
      SDO sdo = this.getSDO();

      try {
         DbTablesQueryRequest queryRequest = (DbTablesQueryRequest)sdo.toQueryRequest(DbTablesQueryRequest.class);
         Map<String, Object> data = this.dbTablesApplication.queryExistTableName(queryRequest);
         return this.toResult(data);
      } catch (Exception var4) {
         return this.error(var4);
      }
   }

   public String saveUserTables() {
      SDO sdo = this.getSDO();
      String id = sdo.getString("parentId");
      DbTablesQueryRequest queryRequest = (DbTablesQueryRequest)sdo.toQueryRequest(DbTablesQueryRequest.class);
      List<Object> plist = sdo.getList("detailData1");
      if (plist != null && plist.size() > 0) {
         id = this.dbTablesApplication.saveUserTables(queryRequest, plist);
      }

      return this.success(id);
   }

   public String deleteUserTables() {
      List<String> ids = this.getSDO().getIds();
      this.dbTablesApplication.deleteUserTables(ids);
      return this.success();
   }

   public String deleteModelClassData() {
      List<String> ids = this.getSDO().getIds();
      this.dbTablesApplication.deleteModelClassData(ids);
      return this.success();
   }

   public String loadModelClassDetail() {
      SDO sdo = this.getSDO();
      String id = sdo.getString("id");
      String parentId = sdo.getString("parentId");
      if (!"".equals(id)) {
         DbTables dbTables = (DbTables)this.dbTablesRepository.findOne(id);
         return this.forward("databaseClassData", dbTables);
      } else {
         this.putAttribute("id", id);
         this.putAttribute("parentId", parentId);
         return this.forward("databaseClassData");
      }
   }

   public String saveModelClassData() {
      SDO sdo = this.getSDO();
      String id = sdo.getString("id");
      DbTables dbTables = null;
      if (!"".equals(id)) {
         dbTables = (DbTables)this.dbTablesRepository.findOne(id);
         dbTables.setTableName(sdo.getString("tableName"));
         dbTables.setName(sdo.getString("name"));
      } else {
         dbTables = new DbTables();
         dbTables.setParentId(sdo.getString("parentId"));
         dbTables.setId(Utils.createUuid());
         dbTables.setTableName(sdo.getString("tableName"));
         dbTables.setName(sdo.getString("name"));
         dbTables.setType("1");
         dbTables.setStatus(1);
      }

      this.dbTablesRepository.save(dbTables);
      return this.success(dbTables.getId());
   }

   public String deleteUserTableFields() {
      List<String> ids = this.getSDO().getIds();
      List<TablesMeta> dblist = this.tablesMetaRepository.findAll(ids);
      this.tablesMetaRepository.delete(dblist);
      return this.success();
   }

   public String queryAlternativeMetaLists() {
      SDO sdo = this.getSDO();
      DbTablesQueryRequest queryRequest = (DbTablesQueryRequest)sdo.toQueryRequest(DbTablesQueryRequest.class);
      Map<String, Object> data = this.dbTablesApplication.queryAlternativeMetaLists(queryRequest);
      return this.toResult(data);
   }

   public String querySelectedMetaLists() {
      SDO sdo = this.getSDO();
      DbTablesQueryRequest queryRequest = (DbTablesQueryRequest)sdo.toQueryRequest(DbTablesQueryRequest.class);
      List<Map<String, Object>> data = this.dbTablesApplication.querySelectedMetaLists(queryRequest);
      return this.packGridDataAndResult(data);
   }

   public String publishToModelRecordTable() {
      new HashMap();
      SDO sdo = this.getSDO();
      String modelId = sdo.getString("tableId");
      DbTablesQueryRequest queryRequest = (DbTablesQueryRequest)sdo.toQueryRequest(DbTablesQueryRequest.class);
      Map<String, Object> data = this.dbTablesApplication.publishToModelRecordTable(queryRequest);
      Object map = data.get("result");
      return this.toResult(data);
   }

   public String forwardFormmanageList() {
      return this.forward("formmanageList");
   }
}
