package com.huigou.uasp.util;

import com.google.common.base.CaseFormat;
import com.huigou.data.exception.SQLParseException;
import com.huigou.data.jdbc.util.ParseSQLParam;
import com.huigou.data.query.model.QueryModel;
import com.huigou.exception.ApplicationException;
import com.huigou.util.ClassHelper;
import com.huigou.util.LogHome;
import com.huigou.util.StringUtil;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.net.InetAddress;
import java.net.NetworkInterface;
import java.net.UnknownHostException;
import java.sql.Timestamp;
import java.text.NumberFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Comparator;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import java.util.Map.Entry;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.regex.PatternSyntaxException;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipOutputStream;
import javax.persistence.Column;
import javax.persistence.Embedded;
import javax.persistence.Transient;
import org.apache.commons.collections.MapUtils;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.util.Assert;

public class ComUtils {
   protected static final Pattern pattern = Pattern.compile("\t|\r|\n");
   private static final int BUFFER_SIZE = 2048;
   private SimpleDateFormat sdf = new SimpleDateFormat("yyyy-mm-dd");

   public static String createUuid() {
      UUID u = UUID.randomUUID();
      String uuid = u.toString().replace("-", "").toUpperCase();
      return uuid;
   }

   private static ParseSQLParam getParseSqlParam(String sql, Map<String, Object> param) throws SQLParseException {
      ParseSQLParam parser = new ParseSQLParam();
      parser.parse(sql);
      List<String> names = parser.getParameter();
      Object obj = null;
      Iterator var6 = names.iterator();

      while(var6.hasNext()) {
         Object name = var6.next();
         obj = param.get(name);
         if (obj == null) {
            throw new SQLParseException("未找到参数:" + name + " 对应的数据！");
         }

         parser.addValue(obj);
      }

      return parser;
   }

   private static String toSqlString(String sql, Object[] args) throws ApplicationException {
      String str = sql;

      try {
         if (args != null) {
            for(int i = 0; i < args.length; ++i) {
               try {
                  str = str.replaceFirst("\\?", "'" + args[i] + "'");
               } catch (PatternSyntaxException var5) {
                  var5.printStackTrace();
               }
            }
         }
      } catch (Exception var6) {
         LogHome.getLog().error(var6);
      }

      Matcher matcher = pattern.matcher(str);
      str = matcher.replaceAll("");
      LogHome.getLog().info(str);
      return str;
   }

   public static String getSQLByQueryModel(QueryModel queryModel) {
      ParseSQLParam parser = getParseSqlParam(queryModel.getSql(), queryModel.getQueryParams());
      return toSqlString(parser.getParseSql(), parser.getValues().toArray());
   }

   public static boolean filterType(String fileExt) {
      String allowTypes = "xls,xlsx";
      if (allowTypes != null && !allowTypes.equals("")) {
         String[] types = allowTypes.split(",");
         String[] var6 = types;
         int var5 = types.length;

         for(int var4 = 0; var4 < var5; ++var4) {
            String type = var6[var4];
            if (fileExt.toLowerCase().endsWith(type.toLowerCase())) {
               return true;
            }
         }

         return false;
      } else {
         return true;
      }
   }

   public static boolean isExcel2007(String filePath) {
      return filePath.matches("^.+\\.(?i)(xlsx)$");
   }

   public static boolean isExcel2003(String filePath) {
      return filePath.matches("^.+\\.(?i)(xls)$");
   }

   public static String getStringCellValue(Cell cell) {
      new SimpleDateFormat("yyyy-mm-dd");
      String strCell = "";
      switch(cell.getCellType()) {
      case 0:
         String formatString = cell.getCellStyle().getDataFormatString();
         if (formatString.endsWith("%")) {
            NumberFormat percentFormat = NumberFormat.getPercentInstance();
            int dotIndex = formatString.indexOf(".");
            if (dotIndex == -1) {
               percentFormat.setMaximumFractionDigits(0);
            } else {
               percentFormat.setMaximumFractionDigits(formatString.length() - 2 - dotIndex);
            }

            strCell = percentFormat.format(cell.getNumericCellValue());
         } else if ("m/d/yy".equals(formatString)) {
            Timestamp ts = new Timestamp(cell.getDateCellValue().getTime());
            strCell = ts.toString().substring(0, 10);
         } else {
            strCell = String.valueOf(cell.getNumericCellValue());
         }
         break;
      case 1:
         strCell = cell.getStringCellValue();
         break;
      case 2:
      default:
         strCell = "";
         break;
      case 3:
         strCell = "";
         break;
      case 4:
         strCell = String.valueOf(cell.getBooleanCellValue());
      }

      return !strCell.equals("") && strCell != null ? strCell.replace("'", "") : "";
   }

   public static <T> List<Map<String, Object>> impExcel(InputStream in, boolean isExcel2003, Class<T> clazz, String[] tableHeaders, String[] dataTypes) {
      ArrayList resultList = new ArrayList();

      try {
         Workbook hwb = isExcel2003 ? new HSSFWorkbook(in) : new XSSFWorkbook(in);
         Sheet sheet = ((Workbook)hwb).getSheetAt(0);
         int totalRow = sheet.getPhysicalNumberOfRows();
         Assert.isTrue(totalRow > 0, "未正确获取到数据，请检查excel数据!");
         Row headerRow = sheet.getRow(1);
         Row row = null;

         for(int i = 1; i < totalRow; ++i) {
            row = sheet.getRow(i);
            Map<String, Object> rowMap = new HashMap();

            for(int n = 0; n < tableHeaders.length; ++n) {
               String rowValue = "";
               if (row.getCell(n) != null) {
                  rowValue = getStringCellValue(row.getCell(n));
                  if ("date".equals(dataTypes[n])) {
                     rowValue = "to_date('" + rowValue + "','yyyy-mm-dd')";
                  }
               }

               rowMap.put(tableHeaders[n], rowValue);
            }

            resultList.add(rowMap);
         }
      } catch (IOException var23) {
         var23.printStackTrace();
      } finally {
         try {
            in.close();
         } catch (IOException var22) {
            var22.printStackTrace();
         }

      }

      return resultList;
   }

   public static void toZip(String srcDir, OutputStream out, boolean KeepDirStructure) throws RuntimeException {
      long start = System.currentTimeMillis();
      ZipOutputStream zos = null;

      try {
         zos = new ZipOutputStream(out);
         File sourceFile = new File(srcDir);
         compress(sourceFile, zos, sourceFile.getName(), KeepDirStructure);
         long end = System.currentTimeMillis();
         System.out.println("压缩完成，耗时：" + (end - start) + " ms");
      } catch (Exception var16) {
         throw new RuntimeException("zip error from ZipUtils", var16);
      } finally {
         if (zos != null) {
            try {
               zos.close();
            } catch (IOException var15) {
               var15.printStackTrace();
            }
         }

      }

   }

   private static void compress(File sourceFile, ZipOutputStream zos, String name, boolean KeepDirStructure) throws Exception {
      byte[] buf = new byte[2048];
      if (sourceFile.isFile()) {
         zos.putNextEntry(new ZipEntry(name));
         FileInputStream in = new FileInputStream(sourceFile);

         int len;
         while((len = in.read(buf)) != -1) {
            zos.write(buf, 0, len);
         }

         zos.closeEntry();
         in.close();
      } else {
         File[] listFiles = sourceFile.listFiles();
         if (listFiles != null && listFiles.length != 0) {
            File[] var9 = listFiles;
            int var8 = listFiles.length;

            for(int var7 = 0; var7 < var8; ++var7) {
               File file = var9[var7];
               if (KeepDirStructure) {
                  compress(file, zos, name + "/" + file.getName(), KeepDirStructure);
               } else {
                  compress(file, zos, file.getName(), KeepDirStructure);
               }
            }
         } else if (KeepDirStructure) {
            zos.putNextEntry(new ZipEntry(name + "/"));
            zos.closeEntry();
         }
      }

   }

   public static void unZipFiles(File zipFile, String descDir) throws IOException {
      try {
         ZipFile zip = new ZipFile(zipFile);
         Enumeration entries = zip.entries();

         while(entries.hasMoreElements()) {
            ZipEntry entry = (ZipEntry)entries.nextElement();
            String zipEntryName = entry.getName();
            InputStream in = zip.getInputStream(entry);
            String outPath = (descDir + zipEntryName).replaceAll("\\*", "/");
            File file = new File(outPath.substring(0, outPath.lastIndexOf(47)));
            if (!file.exists()) {
               file.mkdirs();
            }

            if (!(new File(outPath)).isDirectory()) {
               OutputStream out = new FileOutputStream(outPath);
               byte[] buf1 = new byte[1024];

               int len;
               while((len = in.read(buf1)) > 0) {
                  out.write(buf1, 0, len);
               }

               in.close();
               out.close();
            }
         }

         zip.close();
      } catch (Exception var12) {
         var12.printStackTrace();
      }

   }

   public static <T> List<T> dataToObject(BufferedReader bre, Class<T> clazz) {
      List<T> resultList = new ArrayList();
      Map<String, Object> rowMap = null;
      String[] tableHeaders = null;
      String line = "";
      String everyLine = "";
      String[] datas = null;

      try {
         int u = 0;

         for(String values = ""; (line = bre.readLine()) != null; ++u) {
            rowMap = new HashMap();
            everyLine = line.replaceAll("\"", "");
            datas = everyLine.split(",");
            if (u == 0) {
               everyLine = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, everyLine);
               tableHeaders = everyLine.split(",");
            } else {
               for(int i = 0; i < tableHeaders.length; ++i) {
                  if (i < datas.length) {
                     values = datas[i].replace("~$~", ",");
                     rowMap.put(tableHeaders[i], values);
                     if ("com.pm.template.domain.model.ProjectTemplate".equals(clazz.getTypeName()) && "nodeType".equals(tableHeaders[i])) {
                        rowMap.put("parentNodeType", values);
                     }

                     if ("id".equals(tableHeaders[i])) {
                        rowMap.put("oldId", values);
                     }
                  } else {
                     rowMap.put(tableHeaders[i], "");
                  }
               }

               resultList.add(ClassHelper.fromMap(clazz, rowMap));
            }
         }
      } catch (IOException var21) {
         try {
            bre.close();
         } catch (IOException var20) {
            var20.printStackTrace();
         }

         var21.printStackTrace();
      } finally {
         try {
            bre.close();
         } catch (IOException var19) {
            var19.printStackTrace();
         }

      }

      return resultList;
   }

   public static InetAddress getLocalHostLANAddress() throws UnknownHostException {
      try {
         InetAddress candidateAddress = null;
         Enumeration ifaces = NetworkInterface.getNetworkInterfaces();

         while(ifaces.hasMoreElements()) {
            NetworkInterface iface = (NetworkInterface)ifaces.nextElement();
            Enumeration inetAddrs = iface.getInetAddresses();

            while(inetAddrs.hasMoreElements()) {
               InetAddress inetAddr = (InetAddress)inetAddrs.nextElement();
               if (!inetAddr.isLoopbackAddress()) {
                  if (inetAddr.isSiteLocalAddress()) {
                     return inetAddr;
                  }

                  if (candidateAddress == null) {
                     candidateAddress = inetAddr;
                  }
               }
            }
         }

         if (candidateAddress != null) {
            return candidateAddress;
         } else {
            InetAddress jdkSuppliedAddress = InetAddress.getLocalHost();
            if (jdkSuppliedAddress == null) {
               throw new UnknownHostException("The JDK InetAddress.getLocalHost() method unexpectedly returned null.");
            } else {
               return jdkSuppliedAddress;
            }
         }
      } catch (Exception var5) {
         UnknownHostException unknownHostException = new UnknownHostException("Failed to determine LAN address: " + var5);
         unknownHostException.initCause(var5);
         throw unknownHostException;
      }
   }

   public static Integer getSysYear() {
      Calendar date = Calendar.getInstance();
      String year = String.valueOf(date.get(1));
      return Integer.parseInt(year);
   }

   public static Map<String, Object> getMapByExcelRow(Row row, boolean... isHeader) {
      int cellTotal = row.getPhysicalNumberOfCells();
      Map<String, Object> result = new HashMap();

      for(int i = 0; i < cellTotal; ++i) {
         Cell cell = row.getCell(i);
         String value = getStringCellValue(cell);
         if (isHeader.length != 0 && isHeader[0]) {
            if (StringUtil.isNotBlank(value)) {
               result.put("col" + String.format("%03d", i), value);
            }
         } else {
            if (StringUtil.isNotBlank(value) && StringUtil.isNumber(value)) {
               value = value.replaceAll("0+$", "").replaceAll("[.]$", "");
            }

            result.put("col" + String.format("%03d", i), value);
         }
      }

      return result;
   }

   public static Map<String, Object> getExcelTableHeader(Sheet sheet) {
      int totalRow = sheet.getPhysicalNumberOfRows();
      Assert.isTrue(totalRow > 0, "未正确获取到数据，请检查excel数据!");
      Row headerRow = sheet.getRow(0);
      return getMapByExcelRow(headerRow, true);
   }

   public static Map<String, Object> getExcelDatas(Sheet sheet, Map<String, Object>... baseMaps) {
      int totalRow = sheet.getPhysicalNumberOfRows();
      Assert.isTrue(totalRow > 0, "未正确获取到数据，请检查excel数据!");
      Map<String, Object> result = new HashMap();
      List<Map<String, Object>> rows = new ArrayList();

      for(int i = 1; i < totalRow; ++i) {
         Row row = sheet.getRow(i);
         Map<String, Object> rowMap = getMapByExcelRow(row);
         Map[] var11 = baseMaps;
         int var10 = baseMaps.length;

         for(int var9 = 0; var9 < var10; ++var9) {
            Map<String, Object> baseMap = var11[var9];
            Map<String, Object> _baseMap = new HashMap();
            _baseMap.putAll(baseMap);
            _baseMap.putAll((Map)rowMap);
            rowMap = _baseMap;
         }

         rows.add(rowMap);
      }

      result.put("Rows", rows);
      result.put("Total", rows.size());
      return result;
   }

   public static String getMultiInsertSqlByList(String tableName, List<Map<String, Object>> datas, String columns) {
      String itStr = String.format(" into %s(%s) values (%s)", tableName, columns, "%s");
      StringBuffer intoSql = new StringBuffer();
      String[] columnNames = columns.split(",");
      Iterator var7 = datas.iterator();

      while(var7.hasNext()) {
         Map<String, Object> map = (Map)var7.next();
         StringBuffer valuesSql = new StringBuffer();
         String[] var12 = columnNames;
         int var11 = columnNames.length;

         for(int var10 = 0; var10 < var11; ++var10) {
            String key = var12[var10];
            String value = MapUtils.getString(map, key, "");
            if (key.equalsIgnoreCase("id")) {
               if (map.get("id") != null && !"".equals(map.get("id").toString())) {
                  valuesSql.append(String.format(",'%s'", value));
               } else {
                  valuesSql.append(",sys_guid()");
               }
            } else if (key.equalsIgnoreCase("created_date")) {
               valuesSql.append(",sysdate");
            } else if (value.startsWith("to_date(")) {
               valuesSql.append(String.format(",%s", value));
            } else {
               value = value.replace("'", "''");
               valuesSql.append(String.format(",'%s'", value));
            }
         }

         intoSql.append(String.format(itStr, valuesSql.substring(1)));
      }

      String sql = String.format("insert all %s select * from dual", intoSql.toString());
      return sql.toString();
   }

   public static String getMultiUpdateColumnSqlByList(List<Map<String, Object>> fieldList, String columns) {
      String[] _columns = columns.split(",");

      for(int i = 0; i < _columns.length; ++i) {
         if (fieldList != null && !"id".equals(_columns[i])) {
            Iterator var5 = fieldList.iterator();

            while(var5.hasNext()) {
               Map<String, Object> map = (Map)var5.next();
               if (map.get("fieldCode").equals(_columns[i])) {
                  if ("date".equals(map.get("fieldType").toString())) {
                     _columns[i] = String.format("%s =to_date(?,'yyyy-mm-dd hh24:mi:ss')", _columns[i]);
                  } else {
                     _columns[i] = String.format("%s = ?", _columns[i]);
                  }
                  break;
               }
            }
         }

         if ("is_audit".equals(_columns[i])) {
            _columns[i] = String.format("%s = ?", _columns[i]);
         }
      }

      return String.join(",", _columns);
   }

   public static String getMultiUpdateColumnSqlByReceiveData(List<Map<String, Object>> fieldList, String columns) {
      String[] _columns = columns.split(",");

      for(int i = 0; i < _columns.length; ++i) {
         if (fieldList != null && !"id".equals(_columns[i])) {
            _columns[i] = String.format("%s = ?", _columns[i]);
         }

         if ("is_audit".equals(_columns[i])) {
            _columns[i] = String.format("%s = ?", _columns[i]);
         }
      }

      return String.join(",", _columns);
   }

   public static List<Object[]> convertListMapToListObjects(List<Map<String, Object>> datas, String columns) {
      List<String> _columns = Arrays.asList(columns.split(","));
      Assert.isTrue(StringUtil.isNotBlank(columns) && _columns.contains("id"), "columns中必须包含id字段");
      List<Object[]> result = new ArrayList();
      int size = _columns.size();

      Object[] objs;
      for(Iterator var6 = datas.iterator(); var6.hasNext(); result.add(objs)) {
         Map<String, Object> map = (Map)var6.next();
         objs = new Object[size];
         if (!StringUtil.isBlank(MapUtils.getString(map, "id"))) {
            int i = 0;

            for(int idx = 0; i < size; ++i) {
               if (!"id".equalsIgnoreCase((String)_columns.get(i))) {
                  objs[idx] = MapUtils.getString(map, _columns.get(i), "");
                  ++idx;
               }
            }

            objs[size - 1] = MapUtils.getString(map, "id");
         }
      }

      return result;
   }

   public static List<String> getColumnnamesByClass(Class<?> cls, String... otherColumns) {
      ArrayList<String> names = new ArrayList();
      Field[] fields = cls.getDeclaredFields();
      if (!cls.getSuperclass().getSimpleName().equals("Object")) {
         names.addAll(getColumnnamesByClass(cls.getSuperclass()));
      }

      Field[] var7 = fields;
      int var6 = fields.length;

      int var5;
      for(var5 = 0; var5 < var6; ++var5) {
         Field field = var7[var5];
         if (!Modifier.isFinal(field.getModifiers()) && !field.isAnnotationPresent(Transient.class)) {
            if (field.isAnnotationPresent(Embedded.class)) {
               names.addAll(getColumnnamesByClass(field.getType()));
            } else {
               Column cm = (Column)field.getAnnotation(Column.class);
               if (cm == null) {
                  names.add(field.getName().toUpperCase());
               } else {
                  names.add(cm.name().toUpperCase());
               }
            }
         }
      }

      if (otherColumns != null && otherColumns.length > 0) {
         String[] var10 = otherColumns;
         var6 = otherColumns.length;

         for(var5 = 0; var5 < var6; ++var5) {
            String columnName = var10[var5];
            names.add(columnName.toUpperCase());
         }
      }

      return names;
   }

   public static String createExcelXml(Map<String, Object>... maps) {
      StringBuffer excelHead = new StringBuffer("<tables><table>");
      if (maps.length > 0 && maps[0] != null && !maps[0].isEmpty()) {
         List<String> columnCodeList = new ArrayList();
         excelHead.append("<row>");
         List<Map<String, Object>> headers = (List)maps[0].get("Rows");
         String baseAttribute = "";
         Map row;
         if (maps.length > 1 && maps[1] != null && !maps[1].isEmpty()) {
            StringBuffer strBuffer = new StringBuffer();
            row = maps[1];
            Iterator var8 = row.entrySet().iterator();

            while(var8.hasNext()) {
               Entry<String, Object> entry = (Entry)var8.next();
               strBuffer.append(String.format("%s='%s' ", entry.getKey(), entry.getValue()));
            }

            baseAttribute = strBuffer.toString();
         }

         Iterator var12 = headers.iterator();

         while(var12.hasNext()) {
            Map<String, Object> headerColumn = (Map)var12.next();
            String columnName = MapUtils.getString(headerColumn, "columnCode");
            columnName = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, columnName);
            columnCodeList.add(columnName);
            excelHead.append(String.format("<col %s>%s</col>", baseAttribute, MapUtils.getString(headerColumn, "columnName")));
         }

         excelHead.append("</row>");
         if (maps.length > 2 && maps[2] != null && !maps[2].isEmpty() && (Integer)maps[2].get("Total") > 0) {
            List<Map<String, Object>> datas = (List)maps[2].get("Rows");
            Iterator var14 = datas.iterator();

            while(var14.hasNext()) {
               row = (Map)var14.next();
               excelHead.append("<row>");
               Iterator var9 = columnCodeList.iterator();

               while(var9.hasNext()) {
                  String columnName = (String)var9.next();
                  excelHead.append(String.format("<col>%s</col>", MapUtils.getString(row, columnName)));
               }

               excelHead.append("</row>");
            }
         }
      }

      excelHead.append("</table></tables>");
      return excelHead.toString();
   }

   public static void copyFile(File fromFile, File toFile) throws IOException {
      FileInputStream ins = new FileInputStream(fromFile);
      FileOutputStream out = new FileOutputStream(toFile);
      byte[] b = new byte[1024];
      boolean var5 = false;

      int n;
      while((n = ins.read(b)) != -1) {
         out.write(b, 0, n);
      }

      ins.close();
      out.close();
   }

   public static void delFolder(String folderPath) {
      try {
         delAllFile(folderPath);
         String filePath = folderPath.toString();
         File myFilePath = new File(filePath);
         myFilePath.delete();
      } catch (Exception var3) {
         var3.printStackTrace();
      }

   }

   public static boolean delAllFile(String path) {
      boolean flag = false;
      File file = new File(path);
      if (!file.exists()) {
         return flag;
      } else if (!file.isDirectory()) {
         return flag;
      } else {
         String[] tempList = file.list();
         File temp = null;

         for(int i = 0; i < tempList.length; ++i) {
            if (path.endsWith(File.separator)) {
               temp = new File(path + tempList[i]);
            } else {
               temp = new File(path + File.separator + tempList[i]);
            }

            if (temp.isFile()) {
               temp.delete();
            }

            if (temp.isDirectory()) {
               delAllFile(path + "/" + tempList[i]);
               delFolder(path + "/" + tempList[i]);
               flag = true;
            }
         }

         return flag;
      }
   }

   public static String getNextUpEn(String en) {
      if (en != null && !en.equals("")) {
         char lastE = 90;
         char[] c = en.toCharArray();
         if (c.length > 1) {
            return null;
         } else {
            int now = c[0];
            if (now >= lastE) {
               return null;
            } else {
               char uppercase = (char)(now + 1);
               return String.valueOf(uppercase);
            }
         }
      } else {
         return "A";
      }
   }

   public static class CommonMapComparator implements Comparator<Map<String, Object>> {
      private String compareKey = "";
      private int compareType = 0;
      public static int INT_TYPE = 0;

      public CommonMapComparator() {
      }

      public CommonMapComparator(String compareKey) {
         this.setCompareKey(compareKey);
      }

      public CommonMapComparator(String compareKey, int compareType) {
         this.setCompareKey(compareKey);
         this.setCompareType(compareType);
      }

      public static CommonMapComparator getInstance(String compareKey, int compareType) {
         return new CommonMapComparator(compareKey, compareType);
      }

      public static CommonMapComparator getInstance(String compareKey) {
         return new CommonMapComparator(compareKey);
      }

      public int compare(Map<String, Object> pre, Map<String, Object> next) {
         if (this.getCompareType() == INT_TYPE) {
            int preLv = MapUtils.getIntValue(pre, this.getCompareKey(), 0);
            int nextLv = MapUtils.getIntValue(next, this.getCompareKey(), 0);
            return preLv - nextLv;
         } else {
            return MapUtils.getString(pre, this.getCompareKey(), "").compareTo(MapUtils.getString(next, this.getCompareKey(), ""));
         }
      }

      public String getCompareKey() {
         return this.compareKey;
      }

      public void setCompareKey(String compareKey) {
         this.compareKey = compareKey;
      }

      public int getCompareType() {
         return this.compareType;
      }

      public void setCompareType(int compareType) {
         this.compareType = compareType;
      }
   }
}
