package com.huigou.uasp.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.google.common.base.CaseFormat;
import com.huigou.cache.DictUtil;
import com.huigou.uasp.builder.vo.ParamFormVO;
import com.huigou.uasp.builder.vo.PubDataRecord;
import com.huigou.uasp.builder.vo.SeleListCustomVO;
import java.beans.BeanInfo;
import java.beans.Introspector;
import java.beans.PropertyDescriptor;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.springframework.util.StringUtils;

public class Utils {
   private static String cols = "3";
   private static String labelCols = "2";
   private static String fieldCols = "2";
   private static String textAreaRows = "3";

   public static String createUuid() {
      UUID u = UUID.randomUUID();
      String uuid = u.toString().replace("-", "").toUpperCase();
      return uuid;
   }

   public static void CopyBean(Object source, Object dest) {
      try {
         BeanInfo sourceBean = Introspector.getBeanInfo(source.getClass(), Object.class);
         PropertyDescriptor[] sourceProperty = sourceBean.getPropertyDescriptors();
         BeanInfo destBean = Introspector.getBeanInfo(dest.getClass(), Object.class);
         PropertyDescriptor[] destProperty = destBean.getPropertyDescriptors();
         int i = 0;

         while(i < sourceProperty.length) {
            int j = 0;

            while(true) {
               if (j < destProperty.length) {
                  if (!sourceProperty[i].getName().equals(destProperty[j].getName())) {
                     ++j;
                     continue;
                  }

                  destProperty[j].getWriteMethod().invoke(dest, sourceProperty[i].getReadMethod().invoke(source));
               }

               ++i;
               break;
            }
         }
      } catch (Exception var8) {
         var8.printStackTrace();
      }

   }

   public static String toUpperCaseFirstOne(String s) {
      if ("".equals(s)) {
         return s;
      } else {
         return Character.isUpperCase(s.charAt(0)) ? s : Character.toUpperCase(s.charAt(0)) + s.substring(1);
      }
   }

   public static String toLowerCaseFirstOne(String s) {
      if ("".equals(s)) {
         return s;
      } else {
         return Character.isLowerCase(s.charAt(0)) ? s : Character.toLowerCase(s.charAt(0)) + s.substring(1);
      }
   }

   public static String generateJava(String fileName, StringBuffer code) {
      PrintWriter pw = null;
      FileInputStream fis = null;
      InputStreamReader isr = null;
      BufferedReader br = null;
      String filein = code.toString() + "\r\n";
      String temp = "";
      String backStr = "";

      try {
         File file = new File(fileName);
         if (file.exists()) {
            file.delete();
         }

         file.createNewFile();
         fis = new FileInputStream(file);
         isr = new InputStreamReader(fis);
         br = new BufferedReader(isr);
         StringBuffer buf = new StringBuffer();

         for(int var11 = 1; (temp = br.readLine()) != null; ++var11) {
            buf = buf.append(temp);
            buf = buf.append(System.getProperty("line.separator"));
         }

         buf.append(filein);
         pw = new PrintWriter(new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file), "UTF-8")));
         pw.write(buf.toString().toCharArray());
         pw.flush();
      } catch (Exception var20) {
         backStr = var20.getMessage();
         var20.printStackTrace();
      } finally {
         try {
            br.close();
         } catch (IOException var19) {
            backStr = var19.getMessage();
            var19.printStackTrace();
         }

         pw.close();
      }

      return backStr;
   }

   public static String generateClass(String packName, String clsName) {
      String backStr = "";
      System.out.println("generateClass path===" + packName);
      String libPath = packName.substring(1, packName.length() - 8) + "lib";
      File file = new File(packName + packName + "/" + clsName + ".class");
      if (file.exists()) {
         file.delete();
      }

      String byi = "javac -g  -encoding UTF-8 " + packName + packName + "/" + clsName + ".java" + " -classpath " + libPath + "/*";
      System.out.println("编译文件===" + packName + packName + "/" + clsName + ".java");
      Process process = null;

      try {
         process = Runtime.getRuntime().exec(byi);
         InputStream errorStream = process.getErrorStream();
         InputStreamReader inputStreamReader = new InputStreamReader(errorStream);
         BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
         String line = null;

         while((line = bufferedReader.readLine()) != null) {
            System.out.println(line);
         }

         int exitVal = process.waitFor();
         if (exitVal != 0) {
            System.out.println("编译java文件失败！");
         }
      } catch (Exception var13) {
         backStr = var13.getMessage();
         var13.printStackTrace();
      }

      return backStr;
   }

   public static List<Map<String, Object>> dataFieldTransfer(List<Map<String, Object>> fieldList, List<Map<String, Object>> oldRows) {
      List<Map<String, Object>> newRows = new ArrayList();
      String fieldCode = "";
      String fieldVal = "";
      String displayVal = "";
      Map<String, Object> mapField = null;

      for(int i = 0; i < oldRows.size(); ++i) {
         Map<String, Object> mapRow = (Map)oldRows.get(i);

         for(int j = 0; j < fieldList.size(); ++j) {
            mapField = (Map)fieldList.get(j);
            fieldCode = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, mapField.get("fieldCode").toString());
            fieldVal = mapRow.get(fieldCode).toString();
            mapRow.remove(fieldCode);
            if (mapField.get("dictCode") != null && !"".equals(mapField.get("dictCode"))) {
               displayVal = DictUtil.getDictionaryDetailText(mapField.get("dictCode").toString(), fieldVal);
               mapRow.put("field" + j, displayVal);
               mapRow.put("field" + j + "_dictcode", fieldVal);
            } else if (!"checkbox".equals(mapField.get("fieldTag")) && !"radio".equals(mapField.get("fieldTag"))) {
               mapRow.put("field" + j, fieldVal);
            } else {
               fieldVal = getDataSourceValue(mapField, fieldVal);
               mapRow.put("field" + j, fieldVal);
            }
         }

         newRows.add(mapRow);
      }

      return newRows;
   }

   public static String getDataSourceValue(Map<String, Object> map, String fieldVal) {
      String[] fval = fieldVal.split(",");
      String fvals = "";
      String displayVal = "";
      if ("3".equals(map.get("dataSourceType"))) {
         for(int u = 0; u < fval.length; ++u) {
            displayVal = DictUtil.getDictionaryDetailText(map.get("dataSource").toString(), fval[u]);
            if (!"".equals(fvals)) {
               fvals = fvals + ",";
            }

            fvals = fvals + displayVal;
         }
      } else if ("4".equals(map.get("dataSourceType"))) {
         Map<String, Object> mapval = (Map)JSON.parse(map.get("dataSource").toString());

         for(int u = 0; u < fval.length; ++u) {
            displayVal = mapval.get(fval[u]).toString();
            if (!"".equals(fvals)) {
               fvals = fvals + ",";
            }

            fvals = fvals + displayVal;
         }
      }

      return fvals;
   }

   public static Map<String, Object> dataValueTransfer(List<Map<String, Object>> fieldList, PubDataRecord entity) {
      Map<String, Object> map = new HashMap();
      new HashMap();

      try {
         String vals = "";
         Object obj = null;

         for(int i = 0; i < fieldList.size(); ++i) {
            Map<String, Object> mapfield = (Map)fieldList.get(i);
            obj = ReflectionUtil.invokeGet(entity, "field" + Integer.toString(i));
            if (obj != null && !"".equals(obj.toString())) {
               vals = obj.toString();
               if (StringUtils.isEmpty(entity.getId()) && "date".equals(mapfield.get("fieldType").toString())) {
                  vals = "to_date('" + vals + "','yyyy-mm-dd')";
               } else if ("date".equals(mapfield.get("fieldType").toString())) {
                  vals = vals.substring(0, 10);
               }

               map.put(mapfield.get("fieldCode").toString(), vals);
            }
         }
      } catch (Exception var7) {
         var7.printStackTrace();
      }

      return map;
   }

   public static String getDataFields(List<Map<String, Object>> fieldList, String fieldStyle) {
      String fields = "";
      new HashMap();

      for(int i = 0; i < fieldList.size(); ++i) {
         Map<String, Object> mapData = (Map)fieldList.get(i);
         fields = fields + mapData.get(fieldStyle).toString();
         if (i < fieldList.size() - 1) {
            fields = fields + ",";
         }
      }

      return fields;
   }

   public static String getDataFieldsByAlias(List<Map<String, Object>> fieldList) {
      String fields = "";
      new HashMap();

      for(int i = 0; i < fieldList.size(); ++i) {
         Map<String, Object> mapData = (Map)fieldList.get(i);
         fields = fields + mapData.get("fieldCode").toString() + " field" + Integer.toString(i);
         if (i < fieldList.size() - 1) {
            fields = fields + ",";
         }
      }

      return fields;
   }

   public static String getDataFieldsByMult(List<Map<String, Object>> fieldList) {
      String fields = "";
      String multFields = "";
      new HashMap();

      for(int i = 0; i < fieldList.size(); ++i) {
         Map<String, Object> mapData = (Map)fieldList.get(i);
         if ("0".equals(mapData.get("multiValue").toString())) {
            fields = fields + mapData.get("fieldCode").toString();
         } else {
            multFields = multFields + mapData.get("attrCode").toString() + ":";
            multFields = multFields + mapData.get("fieldCode").toString();
         }

         if (!"".equals(fields) && !fields.endsWith(",")) {
            fields = fields + ",";
         }

         if (!"".equals(multFields) && !fields.endsWith(",")) {
            multFields = multFields + ",";
         }
      }

      if (!"".equals(fields)) {
         fields = fields.substring(0, fields.length() - 1);
      }

      if (!"".equals(multFields)) {
         multFields = multFields.substring(0, multFields.length() - 1);
      }

      return fields + ";" + multFields;
   }

   public static String getSearchDataFields(List<Map<String, Object>> fieldList) {
      String searchField = "";
      new HashMap();

      for(int i = 0; i < fieldList.size(); ++i) {
         Map<String, Object> mapData = (Map)fieldList.get(i);
         if (mapData.get("searchField") != null && "1".equals(mapData.get("searchField").toString())) {
            searchField = searchField + mapData.get("fieldCode").toString();
            if (i < fieldList.size() - 1) {
               searchField = searchField + ",";
            }
         }
      }

      return searchField;
   }

   public static ParamFormVO composeAttributes(List<Map<String, Object>> srclist, String tableName, String tableDesc, List<String> hiddenFields) {
      String[] fieldEns = new String[srclist.size()];
      String[] fieldChs = new String[srclist.size()];
      String[] realFieldEns = new String[srclist.size()];
      String[] fieldTags = new String[srclist.size()];
      String[] fieldTypes = new String[srclist.size()];
      String[] mustinputFields = new String[srclist.size()];
      String[] validatorTypes = new String[srclist.size()];
      String[] dataSourceTypes = new String[srclist.size()];
      String[] dataSources = new String[srclist.size()];
      String[] codeRuleIds = new String[srclist.size()];
      String[] maxLengths = new String[srclist.size()];
      Integer[] readOnlys = new Integer[srclist.size()];
      String[] cssStyles = new String[srclist.size()];
      String[] checkFunctions = new String[srclist.size()];
      String[] jsFunctions = new String[srclist.size()];
      String[] searchFields = new String[srclist.size()];
      String displayFieldStr = "";
      String displayFieldNameStr = "";
      String displayFieldTypeStr = "";
      Map<String, Object> map = null;

      for(int i = 0; i < srclist.size(); ++i) {
         map = (Map)srclist.get(i);
         fieldEns[i] = map.get("fieldCode").toString();
         realFieldEns[i] = fieldEns[i];
         fieldEns[i] = "field" + i;
         fieldChs[i] = map.get("fieldName").toString();
         if (map.get("fieldDecimal") != null && !"".equals(map.get("fieldDecimal").toString()) && Integer.parseInt(map.get("fieldDecimal").toString()) > 0) {
            fieldTypes[i] = map.get("fieldType").toString() + "2";
         } else {
            fieldTypes[i] = map.get("fieldType").toString();
         }

         fieldTags[i] = map.get("fieldTag").toString();
         mustinputFields[i] = map.get("mustInput").toString();
         validatorTypes[i] = map.get("dataFormat").toString();
         codeRuleIds[i] = map.get("codeRuleId").toString();
         maxLengths[i] = map.get("maxLength") != null && !"".equals(map.get("maxLength").toString()) ? map.get("maxLength").toString() : map.get("fieldLength").toString();
         readOnlys[i] = map.get("readOnly") != null && !"".equals(map.get("readOnly").toString()) ? Integer.parseInt(map.get("readOnly").toString()) : 0;
         cssStyles[i] = map.get("cssStyle") != null ? map.get("cssStyle").toString() : "";
         checkFunctions[i] = map.get("checkFunction") != null ? map.get("checkFunction").toString() : "";
         jsFunctions[i] = map.get("jsFunction") != null ? map.get("jsFunction").toString() : "";
         if (map.get("dataSourceType") != null && !"".equals(map.get("dataSourceType").toString())) {
            dataSourceTypes[i] = map.get("dataSourceType").toString();
            dataSources[i] = map.get("dataSource").toString();
            if (map.get("dictCode") != null && !"".equals(map.get("dictCode").toString())) {
               dataSourceTypes[i] = "3";
               dataSources[i] = map.get("dictCode").toString();
            }
         }

         searchFields[i] = map.get("searchField").toString();
         if ("1".equals(map.get("displayListing").toString())) {
            if (!"".equals(displayFieldStr)) {
               displayFieldStr = displayFieldStr + ",";
               displayFieldNameStr = displayFieldNameStr + ",";
               displayFieldTypeStr = displayFieldTypeStr + ",";
            }

            displayFieldStr = displayFieldStr + fieldEns[i];
            displayFieldNameStr = displayFieldNameStr + fieldChs[i];
            displayFieldTypeStr = displayFieldTypeStr + fieldTypes[i];
         }
      }

      ParamFormVO paraForm = new ParamFormVO();
      paraForm.setTableName(tableName);
      paraForm.setFormName(tableDesc);
      paraForm.setFieldEns(fieldEns);
      paraForm.setFieldChs(fieldChs);
      paraForm.setFieldTags(fieldTags);
      paraForm.setRealFieldEns(realFieldEns);
      paraForm.setCssStyle(cssStyles);
      paraForm.setCheckFunction(checkFunctions);
      paraForm.setJsFunction(jsFunctions);
      paraForm.setFieldsLengths(maxLengths);
      paraForm.setReadOnlys(readOnlys);
      paraForm.setCodeRuleId(codeRuleIds);
      paraForm.setExistAttachment(0);
      paraForm.setPagedatailCols(cols);
      paraForm.setLabelCols(Integer.parseInt(labelCols));
      paraForm.setFieldCols(Integer.parseInt(fieldCols));
      paraForm.setTextAreaRows(Integer.parseInt(textAreaRows));
      paraForm.setDataSources(dataSources);
      paraForm.setDataSourceTypes(dataSourceTypes);
      paraForm.setMustinputFields(mustinputFields);
      paraForm.setValidatorTypes(validatorTypes);
      paraForm.setHiddenFields(hiddenFields);
      paraForm.setSearchFields(searchFields);
      paraForm.setDisplayFields(displayFieldStr.split(","));
      paraForm.setDisplayFieldnames(displayFieldNameStr.split(","));
      paraForm.setDisplayFieldTypes(displayFieldTypeStr.split(","));
      return paraForm;
   }

   public static String generateFile(String fileName, StringBuffer sb) {
      PrintWriter pw = null;
      String filein = sb.toString() + "\r\n";
      String backStr = "";

      try {
         File file = new File(fileName);
         if (file.exists()) {
            file.delete();
         }

         file.createNewFile();
         StringBuffer buf = new StringBuffer();
         buf.append(filein);
         pw = new PrintWriter(new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file), "UTF-8")));
         pw.write(buf.toString().toCharArray());
         pw.flush();
      } catch (Exception var10) {
         backStr = var10.getMessage();
         var10.printStackTrace();
      } finally {
         pw.close();
      }

      return backStr;
   }

   public static String[] maches(String str, String regex) {
      Pattern p = Pattern.compile(regex);
      Matcher m = p.matcher(str);
      ArrayList list = new ArrayList();

      while(m.find()) {
         list.add(m.group());
      }

      return (String[])list.toArray(new String[0]);
   }

   public static JSONObject parseInputAttrs(String str) {
      String preg_attr = "(\\w+)=\"(.*?)\"";
      List<String[]> list = machesGroup(str, preg_attr);
      JSONObject object = new JSONObject();
      Iterator var5 = list.iterator();

      while(var5.hasNext()) {
         String[] ss = (String[])var5.next();
         object.put(ss[0], ss[1]);
      }

      return object;
   }

   public static <T> T parseInputAttrsT(String str, Class<T> t) {
      JSONObject object = parseInputAttrs(str);
      return JSON.parseObject(object.toJSONString(), t);
   }

   public static List<String[]> machesGroup(String str, String regex) {
      Pattern p = Pattern.compile(regex);
      Matcher m = p.matcher(str);
      ArrayList list = new ArrayList();

      while(m.find()) {
         int cnt = m.groupCount();
         String[] ss = new String[cnt];

         for(int i = 0; i < cnt; ++i) {
            ss[i] = m.group(i + 1);
         }

         list.add(ss);
      }

      return list;
   }

   public static List<String> getHiddenFields(SeleListCustomVO customVo) {
      List<String> hiddenField = new ArrayList();
      if (customVo.getBackFields() != null) {
         String[] backField = customVo.getBackFields().split(",");
         String[] fieldType = customVo.getFieldTypes().split(",");

         for(int u = 0; u < backField.length; ++u) {
            if ("1".equals(fieldType[u])) {
               hiddenField.add(backField[u]);
            }
         }
      }

      return hiddenField;
   }

   public static void composeMainFormCheckFunction(ParamFormVO paraForm, StringBuffer sb) {
      String[] chkFuncions = paraForm.getCheckFunction();
      String[] jsFuncions = paraForm.getJsFunction();
      String[] fields = paraForm.getDisplayFields();
      String[] realFields = paraForm.getRealFieldEns();
      sb.append(" function bindEvent(){ ").append("\r\n");

      int u;
      for(u = 0; u < chkFuncions.length; ++u) {
         if (!"".equals(chkFuncions[u])) {
            sb.append("    $('#").append(fields[u]).append("').on('mouseout',checkFunc_").append(u).append("); ");
            sb.append("\t  $('#").append(fields[u]).append("').bind('blur',checkFunc_").append(u).append("); ");
         }
      }

      for(u = 0; u < jsFuncions.length; ++u) {
         if (!"".equals(jsFuncions[u]) && "".equals(chkFuncions[u])) {
            sb.append("    $('#").append(fields[u]).append("').on('mouseout',jsFunc_").append(u).append("); ");
            sb.append("\t  $('#").append(fields[u]).append("').bind('blur',jsFunc_").append(u).append("); ");
         }
      }

      sb.append(" } ").append("\r\n");
      sb.append("");

      for(u = 0; u < chkFuncions.length; ++u) {
         if (!"".equals(chkFuncions[u])) {
            sb.append(" function  checkFunc_").append(u).append("(){ ").append("\r\n");
            if (!"".equals(jsFuncions[u])) {
               sb.append(" jsFunc_").append(u).append("();").append("\r\n");
            }

            checkMainFormMethod(chkFuncions[u], paraForm, u, sb);
         }
      }

      String jsfunction = "";

      for(int j = 0; j < jsFuncions.length; ++j) {
         if (!"".equals(jsFuncions[j])) {
            jsfunction = jsFuncions[j];
            sb.append(" function  jsFunc_").append(j).append("(){ ").append("\r\n");

            for(int x = 0; x < realFields.length; ++x) {
               jsfunction = jsfunction.replaceAll("#" + realFields[x], "#" + fields[x]);
            }

            sb.append(jsfunction).append("\r\n");
            sb.append(" } ").append("\r\n");
         }
      }

   }

   public static void composeDetailCheckFunction(ParamFormVO paraForm, String[] mainTableFields, StringBuffer sb) {
      String[] chkFuncions = paraForm.getCheckFunction();
      String[] jsFuncions = paraForm.getJsFunction();
      String[] fields = paraForm.getDisplayFields();
      String[] realFields = paraForm.getRealFieldEns();
      sb.append("   function bindEvent(grid){ ");
      String gridName = CaseFormat.LOWER_UNDERSCORE.to(CaseFormat.LOWER_CAMEL, paraForm.getTableName()) + "GridManager";

      for(int u = 0; u < chkFuncions.length; ++u) {
         if (!"".equals(chkFuncions[u])) {
            sb.append("\tvar datas=grid.record; var cols = grid.column;");
            sb.append(" if (cols.name ==\"").append(fields[u]).append("\") { ");
            checkDetailMethod(gridName, chkFuncions[u], paraForm, mainTableFields, u, sb);
            sb.append("  \t }  ");
         }
      }

      String jsfunction = "";

      for(int u = 0; u < jsFuncions.length; ++u) {
         if (!"".equals(jsFuncions[u])) {
            jsfunction = jsFuncions[u];

            int x;
            for(x = 0; x < mainTableFields.length; ++x) {
               jsfunction = jsfunction.replaceAll("#" + mainTableFields[x], "#field" + x);
            }

            for(x = 0; x < realFields.length; ++x) {
               if (jsfunction.indexOf("grid.record." + realFields[x]) > -1) {
                  jsfunction = jsfunction.replace("grid.record." + realFields[x], "grid.record." + fields[x]);
               }

               if (jsfunction.indexOf(".updateCell('" + realFields[x] + "'") > -1) {
                  jsfunction = jsfunction.replace(".updateCell('" + realFields[x] + "'", ".updateCell('" + fields[x] + "'");
               }

               if (jsfunction.indexOf("grid.column.name=='" + realFields[x] + "'") > -1) {
                  jsfunction = jsfunction.replace("grid.column.name=='" + realFields[x] + "'", "grid.column.name=='" + fields[x] + "'");
               }
            }

            sb.append(jsfunction).append("\r\n");
         }
      }

      sb.append("  \t }  ");
   }

   public static void checkMainFormMethod(String chkFuncions, ParamFormVO paraForm, int u, StringBuffer sb) {
      String[] fields = paraForm.getDisplayFields();
      String[] realfields = paraForm.getRealFieldEns();
      String[] checkfuncs = chkFuncions.split(":");
      String[] paraFields = null;
      String[] backFields = null;
      if (checkfuncs.length > 1) {
         paraFields = checkfuncs[1].split(",");
      }

      if (checkfuncs.length > 2) {
         backFields = checkfuncs[2].split(",");
      }

      sb.append("    var currVal=$('#").append(fields[u]).append("').val();").append("\r\n");
      sb.append("    var url=web_app.name + '/dataManage/checkFieldFunction.ajax?funcname=").append(checkfuncs[0]);
      if (checkfuncs.length > 1) {
         sb.append("&paramfield=").append(checkfuncs[1]);
      }

      sb.append("';\r\n");
      sb.append("    Public.ajax(url ,{id:$(\"#id\").val(),currVal:currVal");
      String resField;
      int x;
      if (paraFields != null) {
         resField = "";
         String[] var13 = paraFields;
         int var12 = paraFields.length;

         for(x = 0; x < var12; ++x) {
            String pfield = var13[x];

            for(int j = 0; j < realfields.length; ++j) {
               if (realfields[j].equals(pfield)) {
                  resField = "field" + j;
                  break;
               }
            }

            sb.append(",").append(pfield).append(":$('#").append(resField).append("').val()");
         }
      }

      sb.append("  },").append("\r\n");
      sb.append("   function (data) { ").append("\r\n");
      sb.append("     if (data.flag==0){ //表示效验没有通过  ").append("\r\n");
      sb.append("           Public.tip(data.result);");
      sb.append("          $('#").append(fields[u]).append("').val(\"\");");
      if (backFields != null) {
         sb.append(" \t    } else {  ").append("\r\n");
         sb.append("    var results=data.result.split(\",\");");
         resField = "";

         for(int y = 0; y < backFields.length; ++y) {
            for(x = 0; x < realfields.length; ++x) {
               if (realfields[x].equals(backFields[y])) {
                  resField = "field" + x;
                  break;
               }
            }

            sb.append("  if  (results.length>").append(y).append("){");
            sb.append("      $('#").append(resField).append("').val(results[").append(y).append("])");
            sb.append("  } ");
         }

         sb.append(" \t    }  ").append("\r\n");
      } else {
         sb.append(" \t    } ").append("\r\n");
      }

      sb.append("   }); ").append("\r\n");
      sb.append(" } ").append("\r\n");
      sb.append("");
   }

   public static void checkDetailMethod(String gridName, String chkFuncions, ParamFormVO paraForm, String[] mainTableFields, int u, StringBuffer sb) {
      String[] fields = paraForm.getDisplayFields();
      String[] realfields = paraForm.getRealFieldEns();
      String[] paraFields = null;
      String[] backFields = null;
      String[] checkfuncs = chkFuncions.split(":");
      if (checkfuncs.length > 1) {
         paraFields = checkfuncs[1].split(",");
      }

      if (checkfuncs.length > 2) {
         backFields = checkfuncs[2].split(",");
      }

      sb.append("    var currVal=datas.").append(fields[u]).append("; ").append("\r\n");
      sb.append("    var url=web_app.name + '/dataManage/checkFieldFunction.ajax?funcname=").append(checkfuncs[0]);
      if (checkfuncs.length > 1) {
         sb.append("&paramfield=").append(checkfuncs[1]);
      }

      sb.append("';").append("\r\n");
      sb.append("    Public.ajax(url ,{id:datas.id,currVal:currVal");
      if (paraFields != null) {
         String[] var14 = paraFields;
         int var13 = paraFields.length;

         for(int var12 = 0; var12 < var13; ++var12) {
            String pfield = var14[var12];
            sb.append(",").append(pfield).append(":datas.").append(getToFields(mainTableFields, realfields, pfield)).append("");
         }
      }

      sb.append("  }, ").append("\r\n");
      sb.append("   function (data) { ").append("\r\n");
      sb.append("     if (data.flag==0){ //表示效验没有通过  ").append("\r\n");
      sb.append("           Public.tip(data.result);");
      sb.append("          $('#").append(fields[u]).append("').val(\"\");");
      sb.append(gridName).append(".updateCell('").append(fields[u]).append("','',datas);");
      if (backFields != null) {
         sb.append(" \t    } else {  ").append("\r\n");
         sb.append("        var results=data.result.split(\",\");");

         for(int y = 0; y < backFields.length; ++y) {
            sb.append("  if  (results.length>").append(y).append("){");
            if (backFields[y].startsWith("[") && backFields[y].endsWith("]")) {
               sb.append("    $('#").append(getToFields(mainTableFields, realfields, backFields[y])).append("').val(results[").append(y).append("])");
            } else {
               sb.append(gridName).append(".updateCell('").append(getToFields(mainTableFields, realfields, backFields[y])).append("',results[").append(y).append("],datas);");
            }

            sb.append("  } ");
         }

         sb.append(" \t    } ").append("\r\n");
      } else {
         sb.append(" \t    } ").append("\r\n");
      }

      sb.append("   });").append("\r\n");
      sb.append("");
   }

   public static String getToFields(String[] mainTableFields, String[] realfields, String pfield) {
      String resultField = "";
      int x;
      if (pfield.startsWith("[") && pfield.endsWith("]")) {
         pfield = pfield.substring(1, pfield.length() - 1);

         for(x = 0; x < mainTableFields.length; ++x) {
            if (mainTableFields[x].equals(pfield)) {
               resultField = "field" + x;
               break;
            }
         }
      } else {
         for(x = 0; x < realfields.length; ++x) {
            if (realfields[x].equals(pfield)) {
               resultField = "field" + x;
               break;
            }
         }
      }

      return resultField;
   }
}
