package com.huigou.uasp.bmp.operator.impl;

import com.alibaba.fastjson.JSON;
import com.huigou.data.domain.model.AbstractEntity;
import com.huigou.data.repository.GeneralRepository;
import com.huigou.uasp.bmp.operator.OperatorUIElementPermissionBuilder;
import com.huigou.uasp.bmp.opm.proxy.AccessApplicationProxy;
import com.huigou.uasp.bpm.CooperationModelKind;
import com.huigou.uasp.bpm.engine.application.ProcUnitHandlerApplication;
import com.huigou.uasp.bpm.engine.application.WorkflowApplication;
import com.huigou.uasp.bpm.engine.domain.model.ProcUnitHandler;
import com.huigou.uasp.bpm.engine.domain.query.TaskDetail;
import com.huigou.util.StringUtil;
import org.activiti.bpmn.model.Process;
import org.activiti.bpmn.model.*;
import org.activiti.engine.history.HistoricTaskInstance;
import org.activiti.engine.repository.Deployment;
import org.activiti.engine.repository.ProcessDefinition;
import org.activiti.engine.runtime.ProcessInstance;
import org.activiti.engine.task.Task;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * 界面元素权限查询
 *
 * @author xx
 */

@Service("operatorUIElementPermissionBuilder")
public class OperatorUIElementPermissionBuilderImp implements OperatorUIElementPermissionBuilder {

    @Autowired
    private AccessApplicationProxy accessApplication;
    @Autowired
    protected WorkflowApplication workflowApplication;
    @Autowired
    private GeneralRepository generalRepository;
    @Autowired
    private ProcUnitHandlerApplication procUnitHandlerApplication;

    @Override
    public List<Map<String, Object>> queryUIElementPermissionsByFunction(String function, String personId, boolean isId) {
        if (personId == null) {
            return new ArrayList<>();
        }
        return accessApplication.queryUIElementPermissionsByFunction(function, personId, isId);
    }

    @Override
    public List<Map<String, Object>> queryUIElementPermissionsByProcUnitHandlerId(String id) {
        if (StringUtil.isBlank(id)) {
            return Collections.emptyList();
        }
        return workflowApplication.queryUIElmentPermissionsByProcUnitHandlerId(id);
    }

    @Override
    public List<Map<String, Object>> queryUIElementPermissionsByTaskId(String taskId) {
        TaskDetail taskDetail = workflowApplication.queryTaskDetail(taskId);
        if (taskDetail == null) {
            return Collections.emptyList();
        }
        List<Map<String, Object>> flowElementFieldPermissions = getFlowElementFieldPermissions(taskId);
        // 找出审批规则配置的字段权限
        List<Map<String, Object>> uiElementPermissions = this.queryUIElementPermissionsByProcUnitHandlerId(taskDetail.getProcUnitHandlerId());
        if (uiElementPermissions.size() > 0) {
            return mergeFieldPermissions(flowElementFieldPermissions, uiElementPermissions);
        } else {
            String chiefHandlerId = taskDetail.getProcUnitHandlerId();
            // 协审人的字段权限与主审人保存一致
            ProcUnitHandler procUnitHandler = null;
            if (chiefHandlerId != null) {
                procUnitHandler = procUnitHandlerApplication.loadProcUnitHandler(chiefHandlerId);
                if (procUnitHandler != null && procUnitHandler.getCooperationModelId() == CooperationModelKind.ASSISTANT) {
                    chiefHandlerId = procUnitHandler.getChiefId();
                    procUnitHandler = procUnitHandlerApplication.loadProcUnitHandler(chiefHandlerId);
                }
            }
            String approvalRuleHandlerId = procUnitHandler != null ? procUnitHandler.getApprovalRuleHandlerId() : null;
            flowElementFieldPermissions.forEach(it -> {
                it.put("approvalRuleHandlerId", approvalRuleHandlerId);
                // TODO 暂时标记为主集
                it.put("kindId", "0");
            });
            return flowElementFieldPermissions;
        }
    }

    /**
     * 找出流程图中配置的表单字段权限
     *
     * @param taskId 任务id
     */
    private List<Map<String, Object>> getFlowElementFieldPermissions(String taskId) {
        String processInstanceId, taskDefinitionKey;
        Task task = workflowApplication.getTaskService().createTaskQuery()
                .taskId(taskId)
                .singleResult();
        if (task != null) {
            processInstanceId = task.getProcessInstanceId();
            taskDefinitionKey = task.getTaskDefinitionKey();
        } else {
            HistoricTaskInstance historicTask = workflowApplication.getHistoryService().createHistoricTaskInstanceQuery()
                    .taskId(taskId)
                    .singleResult();
            processInstanceId = historicTask.getProcessInstanceId();
            taskDefinitionKey = historicTask.getTaskDefinitionKey();
        }
        BpmnModel bpmnModel = getBpmnModelByProcessInstanceId(processInstanceId);
        Process process = bpmnModel.getProcesses().get(0);
        FlowElement fe = process.getFlowElement(taskDefinitionKey);
        return getFieldExtensionElement(process, "formNo")
                .map(ExtensionAttribute::getValue)
                .map(formNo -> getFlowElementFieldPermissions(formNo, fe))
                .orElseGet(Collections::emptyList);
    }

    /**
     * 找出流程图中配置的表单字段权限
     *
     * @param formNo 绑定的表单编号
     * @param fe     流程图中的节点
     * @return 流程图中节点的表单字段权限
     */
    private List<Map<String, Object>> getFlowElementFieldPermissions(String formNo, BaseElement fe) {
        return getFieldExtensionElement(fe, "uiElementPermission")
                .map(ExtensionAttribute::getValue)
                .map(JSON::parseObject)
                .map(it -> (Map<String, Object>) it)
                .orElseGet(Collections::emptyMap)
                .entrySet()
                .stream()
                .filter(it -> StringUtils.isNotBlank((String) it.getValue()))
                .map(it -> {
                    String fieldName = it.getKey();
                    List formFields = generalRepository.getEntityManager()
                            .createQuery("select fa from FormAttribute fa inner join SafFormslist f on fa.formId=f.id where f.formNo=:formNo and fa.attrCode=:fieldName")
                            .setParameter("formNo", formNo)
                            .setParameter("fieldName", fieldName)
                            .getResultList();
                    if (formFields.size() > 0) {
                        AbstractEntity formField = (AbstractEntity) formFields.get(0);
                        Map<String, Object> field = new HashMap<>();
                        field.put("operationId", it.getValue());
                        field.put("code", fieldName);
                        field.put("formFieldId", formField.getId());
                        return field;
                    }
                    return null;
                }).filter(Objects::nonNull)
                .collect(Collectors.toList());
    }

    private BpmnModel getBpmnModelByProcessInstanceId(String processInstanceId) {
        ProcessInstance pi = workflowApplication.getRunTimeService().createProcessInstanceQuery()
                .processInstanceId(processInstanceId)
                .singleResult();
        Deployment deployment = workflowApplication.getRepositoryService().createDeploymentQuery()
                .deploymentId(pi.getDeploymentId())
                .singleResult();
        ProcessDefinition pd = workflowApplication.getRepositoryService().createProcessDefinitionQuery()
                .deploymentId(deployment.getId())
                .singleResult();
        return workflowApplication.getRepositoryService().getBpmnModel(pd.getId());
    }

    /**
     * 合并字段权限
     *
     * @param flowElementFieldPermissions 流程图中配置的表单字段权限
     * @param uiElementPermissions        审批规则中配置的字段权限
     */
    private List<Map<String, Object>> mergeFieldPermissions(List<Map<String, Object>> flowElementFieldPermissions, List<Map<String, Object>> uiElementPermissions) {
        return uiElementPermissions.stream()
                .collect(Collectors.groupingBy(it -> (String) it.get("approvalRuleHandlerId")))
                .entrySet().stream()
                .flatMap(entry -> {
                    String approvalRuleHandlerId = entry.getKey();
                    List<Map<String, Object>> permissions = entry.getValue();
                    List<?> uiElementPermissionFormFieldIds = permissions.stream()
                            .map(it -> it.get("formFieldId"))
                            .collect(Collectors.toList());
                    flowElementFieldPermissions.stream()
                            .filter(it -> !uiElementPermissionFormFieldIds.contains(it.get("formFieldId")))
                            .map(it -> {
                                Map<String, Object> copy = new HashMap<>(it);
                                copy.put("approvalRuleHandlerId", approvalRuleHandlerId);
                                return copy;
                            }).forEach(permissions::add);
                    return permissions.stream();
                })
                .collect(Collectors.toList());
    }

    private Optional<ExtensionAttribute> getFieldExtensionElement(BaseElement be, String fieldName) {
        return be.getExtensionElements().getOrDefault("field", Collections.emptyList())
                .stream()
                .flatMap(field -> field.getAttributes().getOrDefault(fieldName, Collections.emptyList()).stream())
                .findAny()
                .filter(attr -> StringUtils.isNotBlank(attr.getValue()));
    }

}
